(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     53760,       1746]*)
(*NotebookOutlinePosition[     54488,       1771]*)
(*  CellTagsIndexPosition[     54444,       1767]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Das Package MrvLimit", "Title"],

Cell["\<\
Das Mathematica-Package MrvLimit ist ein Paket zur Reell-wertigen \
Grenzwertberechnung, insbesondere von exponentiellen und logarithmischen \
Funktionen. Das Package entstand als Ergebnis der Diplomarbeit \"Automatische \
Berechnung von Grenzwerten und Implementierung in Mathematica\" von Udo \
Richter und auf Grundlage der Dissertation \"On Computing Limits in a \
Symbolic Manipulation System\" von Dominik Gruntz.\
\>", "Text"],

Cell[CellGroupData[{

Cell["Laden des Pakets", "Section"],

Cell[TextData[{
  "Das Paket wird wie jedes andere ",
  "Mathematica",
  "-Paket mit ",
  StyleBox["Needs",
    FontFamily->"Courier New"],
  " oder ",
  StyleBox["Get",
    FontFamily->"Courier New"],
  " geladen.\nIst die Datei ",
  StyleBox["MrvLimit.m",
    FontFamily->"Courier New"],
  " in einem Verzeichnis des Mathematica-Suchpfads ",
  StyleBox["$Path",
    FontFamily->"Courier New"],
  ", kann das Paket direkt geladen werden:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Needs["\<MrvLimit`\>"]\)], "Input",
  CellLabel->"In[1]:="],

Cell[BoxData[
    \("MrvLimit v1.0 \[Copyright] 2005 by Udo Richter\n mail: \
udo_richter(at)gmx.de\n web: http://urichter.cjb.net/MrvLimit\n Released \
under the GNU General Public License."\)], "Print",
  CellLabel->"From In[3]:="]
}, Open  ]],

Cell["\<\
Andernfalls muss beim Laden der komplette Pfad zur Datei angegeben werden:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Needs["\<MrvLimit`\>", "\<Pfad/Zur/Datei/MrvLimit.m\>"]\)], "Input",
  CellLabel->"In[1]:="],

Cell[BoxData[
    \("MrvLimit v1.0 \[Copyright] 2005 by Udo Richter\n mail: \
udo_richter(at)gmx.de\n web: http://urichter.cjb.net/MrvLimit\n Released \
under the GNU General Public License."\)], "Print",
  CellLabel->"From In[1]:="]
}, Open  ]],

Cell["\<\
Wird das Paket nur innerhalb eines anderen Pakets ben\[ODoubleDot]tigt, kann \
es auch 'stillschweigend' geladen werden:\
\>", "Text"],

Cell[BoxData[{
    \(\(MrvLimit`MrvLimitLoadSilent = True;\)\), "\[IndentingNewLine]", 
    \(Needs["\<MrvLimit`\>"]\)}], "Input",
  CellLabel->"In[1]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell["Einfache Grenzwertberechnungen", "Section"],

Cell[TextData[{
  "Einfache Grenzwertberechnungen k\[ODoubleDot]nnen analog zu Mathematicas \
",
  StyleBox["Limit",
    FontFamily->"Courier New"],
  "-Funktion durchgef\[UDoubleDot]hrt werden:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(f = x\^2\/\(\((x + 1)\) \((x - 1)\)\);\)\), "\[IndentingNewLine]", 
    \(MrvLimit[f, x \[Rule] \[Infinity]]\)}], "Input",
  CellLabel->"In[2]:="],

Cell[BoxData[
    \(1\)], "Output",
  CellLabel->"Out[3]="]
}, Open  ]],

Cell["\<\
Falls ein eindeutiger Grenzwert nicht existiert, kann die Richtung der Ann\
\[ADoubleDot]herung vorgegeben werden:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MrvLimit[f, x \[Rule] 1, Direction \[Rule] \(-1\)]\)], "Input",
  CellLabel->"In[4]:="],

Cell[BoxData[
    \(\[Infinity]\)], "Output",
  CellLabel->"Out[4]="]
}, Open  ]],

Cell[TextData[{
  "Dabei bedeutet -1 eine Ann\[ADoubleDot]herung von oben, +1 eine Ann\
\[ADoubleDot]herung von unten, und 0 eine beidseitige Ann\[ADoubleDot]herung. \
Falls ",
  StyleBox["MrvLimit",
    FontFamily->"Courier New"],
  " im beidseitigen Modus auf eine Unstetigkeit trifft, werden beide \
einseitigen Grenzwerte als Liste ausgegeben:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MrvLimit[f, x \[Rule] 1]\)], "Input",
  CellLabel->"In[5]:="],

Cell[BoxData[
    \({\(-\[Infinity]\), \[Infinity]}\)], "Output",
  CellLabel->"Out[5]="]
}, Open  ]],

Cell["\<\
Als optisch ansprechende Variante kann die Richtung der \
Ann\[ADoubleDot]herung durch ein hochgestelltes + oder - am Grenzwert \
angegeben werden:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MrvLimit[f, x \[Rule] \(1\^+\)]\)], "Input",
  CellLabel->"In[6]:="],

Cell[BoxData[
    \(\[Infinity]\)], "Output",
  CellLabel->"Out[6]="]
}, Open  ]],

Cell[TextData[{
  "Sollte ",
  StyleBox["MrvLimit",
    FontFamily->"Courier New"],
  " einen Grenzwert nicht korrekt berechnen k\[ODoubleDot]nnen, wird eine \
entsprechende Warnmeldung ausgegeben, und die Grenzwertaufgabe wird \
unausgewertet zur\[UDoubleDot]ck geliefert:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MrvLimit[Sin[1/x], x \[Rule] 0]\)], "Input",
  CellLabel->"In[7]:="],

Cell[BoxData[
    \(MrvLimit::"UnsupportedArgument" \(\(:\)\(\ \)\) 
      "MrvLimit does not support \!\(Sin[x]\) for \!\(x \[Rule] \
\[Infinity]\), appearing in \!\(Sin[x]\)"\)], "Message",
  CellLabel->"From In[7]:="],

Cell[BoxData[
    TagBox[\(MrvLimit[Sin[1\/x], x \[Rule] 0]\),
      HoldForm]], "Output",
  CellLabel->"Out[7]="]
}, Open  ]],

Cell[TextData[{
  "Die Spezialit\[ADoubleDot]t des ",
  StyleBox["MrvLimit",
    FontFamily->"Courier New"],
  "-Algorithmus liegt dabei insbesondere bei Funktionen mit verschachtelten \
Exponential- und Logarithmusfunktionen:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(f = \[ExponentialE]\^x\ \((\(-\[ExponentialE]\^\(1\/x - \
\[ExponentialE]\^\(-\[ExponentialE]\^x\)\)\) + \[ExponentialE]\^\(\
\[ExponentialE]\^\(-x\) + \[ExponentialE]\^\(-x\^2\) + 1\/x\))\);\)\), "\
\[IndentingNewLine]", 
    \(MrvLimit[f, x \[Rule] \[Infinity]]\)}], "Input",
  CellLabel->"In[8]:="],

Cell[BoxData[
    \(1\)], "Output",
  CellLabel->"Out[9]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Limit[f, x \[Rule] \[Infinity]]\)], "Input",
  CellLabel->"In[10]:="],

Cell[BoxData[
    \(Limit[\[ExponentialE]\^x\ \((\(-\[ExponentialE]\^\(\(-\[ExponentialE]\^\
\(-\[ExponentialE]\^x\)\) + 1\/x\)\) + \
\[ExponentialE]\^\(\[ExponentialE]\^\(-x\) + \[ExponentialE]\^\(-x\^2\) + \
1\/x\))\), x \[Rule] \[Infinity]]\)], "Output",
  CellLabel->"Out[10]="]
}, Open  ]],

Cell[TextData[{
  StyleBox["MrvLimit",
    FontFamily->"Courier New"],
  " unterst\[UDoubleDot]tzt die Grundrechenarten +, -, *, /, Potenz und \
Wurzel und die Funktionen ",
  StyleBox["Log, Gamma, LogGamma, PolyGamma, Sin, Cos, Tan, ArcSin, ArcCos, \
ArcTan, Sec, Csc, Cot, ArcSec, ArcCsc",
    FontFamily->"Courier New"],
  " und ",
  StyleBox["ArcCot.",
    FontFamily->"Courier New"]
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Fortgeschrittene Optionen", "Section"],

Cell[TextData[{
  StyleBox["MrvLimit",
    FontFamily->"Courier New"],
  " unterst\[UDoubleDot]tzt einige fortgeschrittene Optionen. Diese Optionen \
k\[ODoubleDot]nnen in beliebiger Reihenfolge angegeben werden."
}], "Text"],

Cell[CellGroupData[{

Cell["Ausgabeformat", "Subsubsection"],

Cell[TextData[{
  "Mittels ",
  StyleBox["Output\[Rule]Limit",
    FontFamily->"Courier New"],
  ", ",
  StyleBox["Output\[Rule]LeadTerm",
    FontFamily->"Courier New"],
  " und ",
  StyleBox["Output\[Rule]SignedZero",
    FontFamily->"Courier New"],
  " kann die Ausgabe von ",
  StyleBox["MrvLimit",
    FontFamily->"Courier New"],
  " ver\[ADoubleDot]ndert werden. Dabei ist ",
  StyleBox["Output\[Rule]Limit",
    FontFamily->"Courier New"],
  " die Standardvorgabe.\n\n",
  StyleBox["Limit[",
    FontFamily->"Courier New"],
  StyleBox["f",
    FontFamily->"Courier New",
    FontSlant->"Italic"],
  StyleBox[",",
    FontFamily->"Courier New"],
  StyleBox["x",
    FontFamily->"Courier New",
    FontSlant->"Italic"],
  StyleBox["\[Rule]",
    FontFamily->"Courier New"],
  StyleBox["lim",
    FontFamily->"Courier New",
    FontSlant->"Italic"],
  StyleBox[", Output\[Rule]SignedZero]",
    FontFamily->"Courier New"],
  " gibt den Grenzwert normal aus, wenn der Grenzwert nicht 0 ist. Ist der \
berechnete Grenzwert 0, wird ",
  StyleBox["entweder ",
    FontFamily->"Times New Roman"],
  StyleBox["Zero",
    FontFamily->"Courier New"],
  StyleBox[" oder ",
    FontFamily->"Times New Roman"],
  StyleBox["-Zero",
    FontFamily->"Courier New"],
  StyleBox[" ausgegeben, je nachdem, ob in der Umgebung des Grenzwertes die \
Funktion positiv oder negativ ist.\n",
    FontFamily->"Times New Roman"],
  "\n",
  StyleBox["Limit[",
    FontFamily->"Courier New"],
  StyleBox["f",
    FontFamily->"Courier New",
    FontSlant->"Italic"],
  StyleBox[",",
    FontFamily->"Courier New"],
  StyleBox["x",
    FontFamily->"Courier New",
    FontSlant->"Italic"],
  StyleBox["\[Rule]",
    FontFamily->"Courier New"],
  StyleBox["lim",
    FontFamily->"Courier New",
    FontSlant->"Italic"],
  StyleBox[", Output\[Rule]LeadTerm]",
    FontFamily->"Courier New"],
  StyleBox[" gibt eine bei der Grenzwertberechnung ermittelte Asymptote",
    FontFamily->"Times New Roman"],
  " aus. Die Ausgabe hat folgendes Format:\n",
  StyleBox["LeadTerm[",
    FontFamily->"Courier New"],
  StyleBox["const",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[",{pwr[",
    FontFamily->"Courier New"],
  Cell[BoxData[
      \(TraditionalForm\`base\_1\)],
    FontSlant->"Italic"],
  StyleBox[",",
    FontFamily->"Courier New"],
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["exp",
            FontSlant->"Italic"], "1"], TraditionalForm]]],
  StyleBox["],pwr[",
    FontFamily->"Courier New"],
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["base",
            FontSlant->"Italic"], "2"], TraditionalForm]]],
  StyleBox[",",
    FontFamily->"Courier New"],
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["exp",
            FontSlant->"Italic"], "2"], TraditionalForm]]],
  StyleBox["],...,pwr[",
    FontFamily->"Courier New"],
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["base",
            FontSlant->"Italic"], "n"], TraditionalForm]]],
  StyleBox[",",
    FontFamily->"Courier New"],
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["exp",
            FontSlant->"Italic"], "n"], TraditionalForm]]],
  StyleBox["]}]\n",
    FontFamily->"Courier New"],
  StyleBox["const",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[" ist der nicht von x abh\[ADoubleDot]ngige Teil der Funktion, ",
    FontFamily->"Times New Roman"],
  StyleBox["\n",
    FontFamily->"Courier New"],
  Cell[BoxData[
      \(TraditionalForm\`base\_i\)]],
  " sind exponentielle Basisfunktionen,\n",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["exp",
            FontSlant->"Italic"], "i"], TraditionalForm]]],
  " sind die reellen, konstanten Exponenten, die die Ordnung \
repr\[ADoubleDot]sentieren, in der die Basisfunktionen auftreten.\nDie zur\
\[UDoubleDot]ckgegebenen Terme sind in interner Darstellung belassen, um \
deren spezielle Struktur zu erhalten. Durch Anwendung der Funktion ",
  StyleBox["FromInternal[",
    FontFamily->"Courier New"],
  StyleBox["f",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[",",
    FontFamily->"Courier New"],
  StyleBox["x",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier New"],
  " kann die allgemeine Mathematica-Darstellung zur\[UDoubleDot]ck gewonnen \
werden. Mehr zur internen Darstellung im Kapitel \[UDoubleDot]ber \
Hilfsfunktionen.\nAlle Basisfunktionen sind Exponentialfunktionen, sind \
positiv und haben f\[UDoubleDot]r ",
  StyleBox["x",
    FontFamily->"Courier New",
    FontSlant->"Italic"],
  StyleBox["\[Rule]",
    FontFamily->"Courier New"],
  StyleBox["lim",
    FontFamily->"Courier New",
    FontSlant->"Italic"],
  " (",
  Cell[BoxData[
      \(TraditionalForm\`x > 0\)]],
  ") den Grenzwert 0.\nDie Basisfunktionen sind dabei nach fallender \
Wachstumsordnung geordnet. Die erste Funktion mit ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[\(exp\_i\),
            FontSlant->"Italic"], "\[NotEqual]", "0"}], TraditionalForm]]],
  " ist dominant und bestimmt das Wachstumsverhalten der Funktion.\n",
  StyleBox["Die Asymptote ist dabei die Funktion ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            RowBox[{
              StyleBox["const",
                FontSlant->"Italic"], 
              StyleBox["*",
                FontSlant->"Plain"], 
              StyleBox[
                SuperscriptBox[
                  SubscriptBox["base", 
                    StyleBox["1",
                      FontSlant->"Plain"]], 
                  SubscriptBox["exp", 
                    StyleBox["1",
                      FontSlant->"Plain"]]],
                FontSlant->"Italic"], "*", 
              StyleBox[
                SuperscriptBox[
                  SubscriptBox["base", 
                    StyleBox["2",
                      FontSlant->"Plain"]], 
                  SubscriptBox["exp", 
                    StyleBox["2",
                      FontSlant->"Plain"]]],
                FontSlant->"Italic"], "*"}], "..."}], "*", 
          StyleBox[\(base\_n\^exp\_n\),
            FontSlant->"Italic"]}], TraditionalForm]]]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(f = \(-\[ExponentialE]\^\(1\/x - \
\[ExponentialE]\^\(-\[ExponentialE]\^x\)\)\) + \[ExponentialE]\^\(\
\[ExponentialE]\^\(-x\) + \[ExponentialE]\^\(-x\^2\) + 1\/x\);\)\), "\
\[IndentingNewLine]", 
    \(lt = 
      MrvLimit[f, x \[Rule] \[Infinity], Output \[Rule] LeadTerm]\)}], "Input",\

  CellLabel->"In[11]:="],

Cell[BoxData[
    \(LeadTerm[
      1, {pwr[\[ExponentialE]\^\(-\[ExponentialE]\^x\), 0], 
        pwr[\[ExponentialE]\^\(-x\^2\), 0], pwr[\[ExponentialE]\^\(-x\), 1], 
        pwr[\[ExponentialE]\^\(-Log[x]\), 0]}]\)], "Output",
  CellLabel->"Out[12]="]
}, Open  ]],

Cell[TextData[{
  "Alle Terme, abgesehen von ",
  Cell[BoxData[
      \(\[ExponentialE]\^\(-x\)\)]],
  ", treten nur scheinbar auf und spielen f\[UDoubleDot]r den Grenzwert keine \
Rolle.\nDie Ausgabe erfolgt hier in der internen Funktionsdarstellung von \
MrvLimit und nicht in normaler Mathematica-Darstellung. Durch die Aufhebung \
der internen Darstellung wird ",
  Cell[BoxData[
      \(\[ExponentialE]\^\(-Log[x]\)\)]],
  "wieder automatisch zu ",
  Cell[BoxData[
      \(1\/x\)]],
  "vereinfacht:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(lt = FromInternal[lt, x]\)], "Input",
  CellLabel->"In[13]:="],

Cell[BoxData[
    \(LeadTerm[
      1, {pwr[\[ExponentialE]\^\(-\[ExponentialE]\^x\), 0], 
        pwr[\[ExponentialE]\^\(-x\^2\), 0], pwr[\[ExponentialE]\^\(-x\), 1], 
        pwr[1\/x, 0]}]\)], "Output",
  CellLabel->"Out[13]="]
}, Open  ]],

Cell["\<\
Durch Ausf\[UDoubleDot]hrung der Potenzen eliminieren sich die scheinbaren \
Basisfunktionen:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(lt = lt /. pwr \[Rule] Power\)], "Input",
  CellLabel->"In[14]:="],

Cell[BoxData[
    \(LeadTerm[1, {1, 1, \[ExponentialE]\^\(-x\), 1}]\)], "Output",
  CellLabel->"Out[14]="]
}, Open  ]],

Cell["Multiplikation aller Terme ergibt die eigentliche Asymptote:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(lt = lt[\([1]\)]*Apply[Times, lt[\([2]\)]]\)], "Input",
  CellLabel->"In[15]:="],

Cell[BoxData[
    \(\[ExponentialE]\^\(-x\)\)], "Output",
  CellLabel->"Out[15]="]
}, Open  ]],

Cell["Die \[CapitalUDoubleDot]berpr\[UDoubleDot]fung zeigt, dass die \
Asymptote gefunden ist:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MrvLimit[f/lt, x \[Rule] \[Infinity]]\)], "Input",
  CellLabel->"In[16]:="],

Cell[BoxData[
    \(1\)], "Output",
  CellLabel->"Out[16]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Cachekontrolle", "Subsubsection"],

Cell[TextData[{
  "Durch Setzen der Option ",
  StyleBox["ClearCache\[Rule]True",
    FontFamily->"Courier New"],
  StyleBox[" wird vor der Grenzwertberechnung eine Leerung des \
Algorithmus-internen Ergebniscache veranlasst. Jeder einmal berechnete \
Grenzwert wird darin aufbewahrt, um wiederholte Berechnungen des gleichen \
Grenztwertes zu verhindern. Eine Leerung des Caches ist erforderlich, wenn \
sich Rahmenbedingungen ver\[ADoubleDot]ndern, die Auswirkungen auf die \
Grenzwertberechnung haben:",
    FontFamily->"Times New Roman"]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Unprotect[Sign]; Sign[a] = 1; Protect[Sign];\), "\[IndentingNewLine]", 
    \(MrvLimit[\[ExponentialE]\^\(a\ x\), x \[Rule] \[Infinity]]\)}], "Input",\

  CellLabel->"In[17]:="],

Cell[BoxData[
    \(\[Infinity]\)], "Output",
  CellLabel->"Out[18]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Unprotect[Sign]; Sign[a] = \(-1\); 
    Protect[Sign];\), "\[IndentingNewLine]", 
    \(MrvLimit[\[ExponentialE]\^\(a\ x\), x \[Rule] \[Infinity]]\)}], "Input",\

  CellLabel->"In[19]:="],

Cell[BoxData[
    \(\[Infinity]\)], "Output",
  CellLabel->"Out[20]="]
}, Open  ]],

Cell[TextData[{
  "Dieses Ergebnis ist falsch, da das angenomme Vorzeichen von ",
  StyleBox["a",
    FontFamily->"Courier New"],
  " Auswirkung auf den Grenzwert hat, und damit das gecachete Ergebnis keine \
G\[UDoubleDot]ltigkeit mehr hat."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MrvLimit[\[ExponentialE]\^\(a\ x\), x \[Rule] \[Infinity], 
      ClearCache \[Rule] True]\)], "Input",
  CellLabel->"In[21]:="],

Cell[BoxData[
    \(0\)], "Output",
  CellLabel->"Out[21]="]
}, Open  ]],

Cell[BoxData[
    \(Unprotect[Sign]; Sign[a] =. ; Protect[Sign];\)], "Input",
  CellLabel->"In[22]:="],

Cell[TextData[{
  StyleBox["Alternativ kann der Cache durch Aufruf von ",
    FontFamily->"Times New Roman"],
  StyleBox["MrvLimitClearCache",
    FontFamily->"Courier New"],
  StyleBox["[]",
    FontFamily->"Times New Roman"],
  StyleBox[" geleert werden.",
    FontFamily->"Times New Roman"],
  StyleBox["\nMrvLimitGetCacheStats",
    FontFamily->"Courier New"],
  "[] liefert eine statistische Ausgabe \[UDoubleDot]ber den Nutzungsgrad des \
Caches:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MrvLimitGetCacheStats[]\)], "Input",
  CellLabel->"In[23]:="],

Cell[BoxData[
    \({CacheHits \[Rule] 52, CacheMisses \[Rule] 13}\)], "Output",
  CellLabel->"Out[23]="]
}, Open  ]],

Cell[TextData[{
  StyleBox["CacheHits",
    FontFamily->"Courier New"],
  " gibt dabei an, wie viele Grenzwertberechnungen durch gecachete Ergebnisse \
vermieden werden konnten, ",
  StyleBox["CacheMisses",
    FontFamily->"Courier New"],
  " gibt an, wie viele Grenzwertberechnungen tats\[ADoubleDot]chlich ausgef\
\[UDoubleDot]hrt wurden."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Debuginformationen", "Subsubsection"],

Cell[TextData[{
  "Mit ",
  StyleBox["Debug",
    FontFamily->"Courier New"],
  "\[Rule]",
  StyleBox["n",
    FontSlant->"Italic"],
  " wird die Debug-Ausgabe des MrvLimit-Algorithmus aktiviert. Dabei gibt ",
  StyleBox["n",
    FontSlant->"Italic"],
  " an, bis zu welcher rekursiven Schachtelungstiefe die Debuginformationen \
ausgegeben werden sollen. ",
  StyleBox["Debug",
    FontFamily->"Courier New"],
  "\[Rule]\[Infinity] gibt Debug-Informationen in beliebier \
Schachtelungstiefe aus."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MrvLimit[E^x, x \[Rule] \[Infinity], Debug \[Rule] 1, 
      ClearCache \[Rule] True]\)], "Input",
  CellLabel->"In[24]:="],

Cell[BoxData[
    TagBox[
      AdjustmentBox[
        InterpretationBox[
          
          RowBox[{"\<\"Enter Level \"\>", "\[InvisibleSpace]", "1", 
            "\[InvisibleSpace]", "\<\" Call \"\>", "\[InvisibleSpace]", 
            
            TagBox[\(MrvLimitInf[\[ExponentialE]\^x, x, 
                Debug \[Rule] \[Infinity]]\),
              HoldForm]}],
          SequenceForm[ "Enter Level ", 1, " Call ", 
            HoldForm[ 
              MrvLimitInf[ 
                power[ E, x], x, Debug -> DirectedInfinity[ 1]]]],
          Editable->False],
        BoxMargins->{{0, 0}, {0, 0}}],
      DisplayForm]], "Print",
  CellLabel->"From In[24]:="],

Cell[BoxData[
    TagBox[
      AdjustmentBox[
        InterpretationBox[\("Calculating limit of "\[InvisibleSpace]\
\[ExponentialE]\^x\),
          SequenceForm[ "Calculating limit of ", 
            power[ E, x]],
          Editable->False],
        BoxMargins->{{0, 0}, {0, 0}}],
      DisplayForm]], "Print",
  CellLabel->"From In[24]:="],

Cell[BoxData[
    TagBox[
      AdjustmentBox[
        InterpretationBox[\("Calculating Mrv set of "\[InvisibleSpace]\
\[ExponentialE]\^x\),
          SequenceForm[ "Calculating Mrv set of ", 
            power[ E, x]],
          Editable->False],
        BoxMargins->{{0, 0}, {0, 0}}],
      DisplayForm]], "Print",
  CellLabel->"From In[24]:="],

Cell[BoxData[
    TagBox[
      AdjustmentBox[
        InterpretationBox[\("\[CapitalOmega]="\[InvisibleSpace]{MrvF[\
\[ExponentialE]\^x, 3, \[Infinity]]}\),
          SequenceForm[ "\[CapitalOmega]=", {
            MrvF[ 
              power[ E, x], 3, 
              DirectedInfinity[ 1]]}],
          Editable->False],
        BoxMargins->{{0, 0}, {0, 0}}],
      DisplayForm]], "Print",
  CellLabel->"From In[24]:="],

Cell[BoxData[
    TagBox[
      AdjustmentBox[
        InterpretationBox[\("\[Omega]="\[InvisibleSpace]\[ExponentialE]\^x\),
          SequenceForm[ "\[Omega]=", 
            power[ E, x]],
          Editable->False],
        BoxMargins->{{0, 0}, {0, 0}}],
      DisplayForm]], "Print",
  CellLabel->"From In[24]:="],

Cell[BoxData[
    TagBox[
      AdjustmentBox[
        InterpretationBox[\("Replacing \[Omega]\[Rule]1/\[Omega]: \[Omega]="\
\[InvisibleSpace]\[ExponentialE]\^\(-x\)\),
          SequenceForm[ "Replacing \[Omega]\[Rule]1/\[Omega]: \[Omega]=", 
            power[ E, 
              Times[ -1, x]]],
          Editable->False],
        BoxMargins->{{0, 0}, {0, 0}}],
      DisplayForm]], "Print",
  CellLabel->"From In[24]:="],

Cell[BoxData[
    TagBox[
      AdjustmentBox[
        InterpretationBox[\("Prepare to rewrite g="\[InvisibleSpace]\
\[ExponentialE]\^x\[InvisibleSpace]" to A*\[Omega]^c"\),
          SequenceForm[ "Prepare to rewrite g=", 
            power[ E, x], " to A*\[Omega]^c"],
          Editable->False],
        BoxMargins->{{0, 0}, {0, 0}}],
      DisplayForm]], "Print",
  CellLabel->"From In[24]:="],

Cell[BoxData[
    TagBox[
      AdjustmentBox[
        InterpretationBox[\("c="\[InvisibleSpace]\(-1\)\[InvisibleSpace]" A="\
\[InvisibleSpace]1\),
          SequenceForm[ "c=", -1, " A=", 1],
          Editable->False],
        BoxMargins->{{0, 0}, {0, 0}}],
      DisplayForm]], "Print",
  CellLabel->"From In[24]:="],

Cell[BoxData[
    TagBox[
      AdjustmentBox[
        InterpretationBox[\("Rewriting "\[InvisibleSpace]\[ExponentialE]\^x\
\[InvisibleSpace]"\[Rule]"\[InvisibleSpace]1\/\[Omega]\[InvisibleSpace]"\n"\
\[InvisibleSpace]"f="\[InvisibleSpace]1\/\[Omega]\),
          SequenceForm[ "Rewriting ", 
            power[ E, x], "\[Rule]", 
            power[ \[Omega], -1], "\n", "f=", 
            power[ \[Omega], -1]],
          Editable->False],
        BoxMargins->{{0, 0}, {0, 0}}],
      DisplayForm]], "Print",
  CellLabel->"From In[24]:="],

Cell[BoxData[
    TagBox[
      AdjustmentBox[
        InterpretationBox[\("Calculating power series: \
f="\[InvisibleSpace]1\/\[Omega]\),
          SequenceForm[ "Calculating power series: f=", 
            power[ \[Omega], -1]],
          Editable->False],
        BoxMargins->{{0, 0}, {0, 0}}],
      DisplayForm]], "Print",
  CellLabel->"From In[24]:="],

Cell[BoxData[
    TagBox[
      AdjustmentBox[
        InterpretationBox[
          RowBox[{"\<\"Series expansion: \"\>", "\[InvisibleSpace]", 
            InterpretationBox[
              RowBox[{\(1\/\[Omega]\), "+", 
                InterpretationBox[\(O[\[Omega]]\^2\),
                  SeriesData[ \[Omega], 0, {}, -1, 2, 1],
                  Editable->False]}],
              SeriesData[ \[Omega], 0, {1}, -1, 2, 1],
              Editable->False]}],
          SequenceForm[ "Series expansion: ", 
            SeriesData[ \[Omega], 0, {1}, -1, 2, 1]],
          Editable->False],
        BoxMargins->{{0, 0}, {0, 0}}],
      DisplayForm]], "Print",
  CellLabel->"From In[24]:="],

Cell[BoxData[
    TagBox[
      AdjustmentBox[
        InterpretationBox[\("Dominant term: "\[InvisibleSpace]1\/\[Omega]\
\[InvisibleSpace]" , \[Omega]="\[InvisibleSpace]\[ExponentialE]\^\(-x\)\),
          SequenceForm[ "Dominant term: ", 
            power[ \[Omega], -1], " , \[Omega]=", 
            power[ E, 
              Times[ -1, x]]],
          Editable->False],
        BoxMargins->{{0, 0}, {0, 0}}],
      DisplayForm]], "Print",
  CellLabel->"From In[24]:="],

Cell[BoxData[
    TagBox[
      AdjustmentBox[
        InterpretationBox[\("Dominant asymptotic: "\[InvisibleSpace]1\
\[InvisibleSpace]1\/\[ExponentialE]\^\(-x\)\),
          SequenceForm[ "Dominant asymptotic: ", 1, 
            power[ 
              power[ E, 
                Times[ -1, x]], -1]],
          Editable->False],
        BoxMargins->{{0, 0}, {0, 0}}],
      DisplayForm]], "Print",
  CellLabel->"From In[24]:="],

Cell[BoxData[
    TagBox[
      AdjustmentBox[
        InterpretationBox[
          
          RowBox[{"\<\"Leave Level \"\>", "\[InvisibleSpace]", "1", 
            "\[InvisibleSpace]", "\<\" Call \"\>", "\[InvisibleSpace]", 
            
            TagBox[\(MrvLimitInf[\[ExponentialE]\^x, x, 
                  Debug \[Rule] \[Infinity]] \[Equal] \[Infinity]\),
              HoldForm]}],
          SequenceForm[ "Leave Level ", 1, " Call ", 
            HoldForm[ 
              Equal[ 
                MrvLimitInf[ 
                  power[ E, x], x, Debug -> DirectedInfinity[ 1]], 
                DirectedInfinity[ 1]]]],
          Editable->False],
        BoxMargins->{{0, 0}, {0, 0}}],
      DisplayForm]], "Print",
  CellLabel->"From In[24]:="],

Cell[BoxData[
    \(\[Infinity]\)], "Output",
  CellLabel->"Out[24]="]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Hilfsfunktionen", "Section"],

Cell[CellGroupData[{

Cell["ToInternal / FromInternal", "Subsubsection"],

Cell[TextData[{
  "MrvLimit verwendet intern eine Funktionsdarstellung, in der bestimmte \
Funktionen durch alternative Schreibweisen ersetzt werden. Durch diese \
Ersetzung werden st\[ODoubleDot]rende Effekte durch automatische \
Transformationen vermieden. MrvLimit \[UDoubleDot]bersetzt die Eingabe und \
Ausgabe automatisch in die interne Darstellung und zur\[UDoubleDot]ck. Nur \
bei einigen fortgeschrittenen Eingriffsm\[ODoubleDot]glichkeiten trifft man \
auf die interne Darstellung. \n\nFunktionen und ihre interne Darstellung in \
",
  StyleBox["MrvLimit",
    FontFamily->"Courier New"],
  ":\n\n",
  Cell[BoxData[GridBox[{
          {
            StyleBox["Funktion",
              FontWeight->"Bold"], 
            StyleBox["Darstellung",
              FontWeight->"Bold"]},
          {"Power", "power"},
          {"Log", "log"},
          {"Sin", "sin"},
          {"Cos", "cos"},
          {"Tan", "tan"},
          {"ArcSin", "arcsin"},
          {"ArcCos", "arccos"},
          {"ArcTan", "arctan"},
          {"Gamma", "gamma"},
          {"LogGamma", "loggamma"},
          {"PolyGamma", "polygamma"}
          },
        ColumnAlignments->{Left}]]],
  "\n\nDie Anzeige der Funktionen durch Mathematica entspricht jeweils der \
normalen Anzeige:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(power[E, x] + Power[E, x]\)], "Input",
  CellLabel->"In[25]:="],

Cell[BoxData[
    \(\[ExponentialE]\^x + \[ExponentialE]\^x\)], "Output",
  CellLabel->"Out[25]="]
}, Open  ]],

Cell[TextData[{
  "Zur Konvertierung ",
  "zwischen Mathematica-Darstellun",
  "g und normaler Darstellung dienen die Hilfsfunktionen ",
  StyleBox["ToInternal[",
    FontFamily->"Courier New"],
  StyleBox["f",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[",",
    FontFamily->"Courier New"],
  StyleBox["x",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier New"],
  " und ",
  StyleBox["FromInternal[",
    FontFamily->"Courier New"],
  StyleBox["f",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[",",
    FontFamily->"Courier New"],
  StyleBox["x",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier New"],
  ":"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(f = ToInternal[E^x*Sin[x]^c, x]\)], "Input",
  CellLabel->"In[26]:="],

Cell[BoxData[
    \(\[ExponentialE]\^x\ Sin[x]\^c\)], "Output",
  CellLabel->"Out[26]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(f = f /. c \[Rule] 0\)], "Input",
  CellLabel->"In[27]:="],

Cell[BoxData[
    \(\[ExponentialE]\^x\ Sin[x]\^0\)], "Output",
  CellLabel->"Out[27]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(FromInternal[f, x]\)], "Input",
  CellLabel->"In[28]:="],

Cell[BoxData[
    \(\[ExponentialE]\^x\)], "Output",
  CellLabel->"Out[28]="]
}, Open  ]],

Cell[TextData[{
  StyleBox["ToInternal",
    FontFamily->"Courier New"],
  " verarbeitet nur Funktionen, die f\[UDoubleDot]r den Algorithmus als \
bekannt gelten:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ToInternal[Foo[x], x]\)], "Input",
  CellLabel->"In[29]:="],

Cell[BoxData[
    \(MrvLimit::"UnsupportedFunction" \(\(:\)\(\ \)\) 
      "MrvLimit does not support this function: \!\(Foo[x]\)"\)], "Message",
  CellLabel->"From In[29]:="],

Cell[BoxData[
    TagBox[\(ToInternal[Foo[x], x]\),
      HoldForm]], "Output",
  CellLabel->"Out[29]="]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Erweiterungsschnittstellen", "Section"],

Cell[CellGroupData[{

Cell["Potenzreihen", "Subsubsection"],

Cell[TextData[{
  StyleBox["MrvLimit",
    FontFamily->"Courier New"],
  " ist abh\[ADoubleDot]ngig von einem guten Algorithmus zur \
Potenzreihenentwicklung, kann selbst aber nur auf die \
beschr\[ADoubleDot]nkten M\[ODoubleDot]glichkeiten des ",
  StyleBox["Series",
    FontFamily->"Courier New"],
  "-Kommandos von Mathematica zur\[UDoubleDot]ckgreifen. Oft \
gen\[UDoubleDot]gt aber schon eine kleine Modifikation an der auftretenden \
Funktion, um die Potenzreihe zu ermitteln. Oder es steht ein \
g\[ADoubleDot]nzlich anderer Algorithmus zur Potenzreihenentwicklung zur Verf\
\[UDoubleDot]gung. \[CapitalUDoubleDot]ber die Variable ",
  StyleBox["$MrvSeriesHead",
    FontFamily->"Courier New"],
  " kann eine solche Methode eingebunden werden:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MrvLimit[\((\[ExponentialE]\^x\ x)\)\^\(1\/x\), 
      x \[Rule] \[Infinity]]\)], "Input",
  CellLabel->"In[30]:="],

Cell[BoxData[
    \(MrvLimit::"SeriesFail" \(\(:\)\(\ \)\) 
      "Series failed at \
\!\(\[ExponentialE]\^\(\(Log[\(\(x\/\[Omega]\)\)]\)\/x\)\)"\)], "Message",
  CellLabel->"From In[30]:="],

Cell[BoxData[
    TagBox[\(MrvLimit[\((\[ExponentialE]\^x\ x)\)\^\(1\/x\), 
        x \[Rule] \[Infinity]]\),
      HoldForm]], "Output",
  CellLabel->"Out[30]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(SeriesHelper[f_, x_, \[Omega]_, log\[Omega]_, dprint_] := 
        Module[{}, \[IndentingNewLine]If[
            FromInternal[f, 
                x] === \((x\/\[Omega])\)\^\(1\/x\), \
\[IndentingNewLine]\(Return[{ToInternal[\[ExponentialE]\^\(1 + Log[x]\/x\), 
                    x], 0}];\)\[IndentingNewLine]]; \
\[IndentingNewLine]MrvSeriesHead[f, x, \[Omega], log\[Omega], 
            dprint]\[IndentingNewLine]];\)\), "\[IndentingNewLine]", 
    \(\($MrvSeriesHead = SeriesHelper;\)\), "\[IndentingNewLine]", 
    \(\(res = 
        MrvLimit[\((\[ExponentialE]\^x\ x)\)\^\(1\/x\), 
          x \[Rule] \[Infinity], 
          ClearCache \[Rule] True];\)\), "\[IndentingNewLine]", 
    \(\($MrvSeriesHead = MrvSeriesHead;\)\), "\[IndentingNewLine]", 
    \(res\)}], "Input",
  CellLabel->"In[31]:="],

Cell[BoxData[
    \(\[ExponentialE]\)], "Output",
  CellLabel->"Out[35]="]
}, Open  ]],

Cell[TextData[{
  "F\[UDoubleDot]r die genaue Implementation der Schnittstelle sollte der \
Quelltext der Funktion ",
  StyleBox["MrvSeriesHead",
    FontFamily->"Courier New"],
  " herangezogen werden."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Nulltests", "Subsubsection"],

Cell[TextData[{
  "Genau wie das Series-Kommando von Mathematica sind auch die Nulltests eine \
kritische Schw\[ADoubleDot]che des Algorithmus. Auch sie k\[ODoubleDot]nnen \
einfach ersetzt werden. ",
  StyleBox["$MrvTestZero",
    FontFamily->"Courier New"],
  " verweist auf eine Funktion, die zum Testen von Termen auf den Wert 0 \
verwendet wird. Die Standardvorgabe ist ",
  StyleBox["$MrvTestZero=MrvTestZero",
    FontFamily->"Courier New"],
  " mit:\n\n",
  StyleBox["MrvTestZero[term_,x_]:=Simplify[FromInternal[term,x]==0];\n",
    FontFamily->"Courier New"],
  StyleBox["\nAlternativ bietet sich die schnellere, aber ungenauere folgende \
Variante an:\n",
    FontFamily->"Times New Roman"],
  StyleBox["FromInternal[term,x]==0",
    FontFamily->"Courier New"],
  StyleBox[",\noder die gr\[UDoubleDot]ndlichere, aber erheblich langsamere \
folgende Variante: \n",
    FontFamily->"Times New Roman"],
  StyleBox["Simplify[FromInternal[term,x]==0,Element[x,Reals]]",
    FontFamily->"Courier New"],
  StyleBox[". \nMathematica steuert au\[SZ]erdem noch die folgende Variante \
bei:\n",
    FontFamily->"Times New Roman"],
  StyleBox["Developer`ZeroQ[FromInternal[term,x]]",
    FontFamily->"Courier New"],
  StyleBox["\n\n",
    FontFamily->"Times New Roman"],
  "Um Funktionen in der Umgebung eines Grenzwertes (normalerweise \
\[Infinity]) auf die Nullfunktion zu testen, wird ",
  StyleBox["$MrvTestZeroInterval",
    FontFamily->"Courier New"],
  " verwendet. Die Standardvorgabe ist hierbei ",
  StyleBox["$MrvTestZeroInterval = MrvTestZeroInterval",
    FontFamily->"Courier New"],
  ", definiert als:",
  StyleBox["\n\n",
    FontFamily->"Times New Roman"],
  StyleBox["MrvTestZeroInterval[term_,x_\[Rule]\[Infinity]]:=Simplify[\
FromInternal[term,x]==0];",
    FontFamily->"Courier New"],
  StyleBox["\n\nNeben den bereits genannten Varianten kann hier auch die \
konkrete Umgebung ber\[UDoubleDot]cksichtigt werden, zum Beispiel mit ",
    FontFamily->"Times New Roman"],
  StyleBox["Simplify[FromInternal[term,x]==0,x>10^1000]",
    FontFamily->"Courier New"],
  StyleBox[". Leider ist auch dieser Aufruf mit unkalkulierbaren Laufzeiten \
verbunden, weshalb als Standard nur ein einfacher Nulltest ohne Bezug auf x \
durchgef\[UDoubleDot]hrt wird.",
    FontFamily->"Times New Roman"]
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Debugausgabe", "Subsubsection"],

Cell[TextData[{
  "Falls man an einer anderen Ausgabeform der ",
  StyleBox["Debug",
    FontFamily->"Courier New"],
  "-Option interessiert ist, kann man diese \[UDoubleDot]ber ",
  StyleBox["$DebugPrint",
    FontFamily->"Courier New"],
  " bekannt machen:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(MyPrint[Indent_, Text__] := 
        Print["\<Debug[\>", Indent, "\<]:\>", 
          Text];\)\), "\[IndentingNewLine]", 
    \(\($DebugPrint = MyPrint;\)\), "\[IndentingNewLine]", 
    \(\(MrvLimit[E^x, x \[Rule] \[Infinity], 
        Debug \[Rule] 1];\)\), "\[IndentingNewLine]", 
    \(\($DebugPrint = IndentPrint;\)\)}], "Input",
  CellLabel->"In[36]:="],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"Debug[\"\>", "\[InvisibleSpace]", "0", 
        "\[InvisibleSpace]", "\<\"]:\"\>", 
        "\[InvisibleSpace]", "\<\"Enter Level \"\>", "\[InvisibleSpace]", "1",
         "\[InvisibleSpace]", "\<\" Call \"\>", "\[InvisibleSpace]", 
        TagBox[\(MrvLimitInf[\[ExponentialE]\^x, x, Debug \[Rule] 1]\),
          HoldForm]}],
      SequenceForm[ "Debug[", 0, "]:", "Enter Level ", 1, " Call ", 
        HoldForm[ 
          MrvLimitInf[ 
            power[ E, x], x, Debug -> 1]]],
      Editable->False]], "Print",
  CellLabel->"From In[54]:="],

Cell[BoxData[
    InterpretationBox[\("Debug["\[InvisibleSpace]0\[InvisibleSpace]"]:"\
\[InvisibleSpace]"Taking cached result"\),
      SequenceForm[ "Debug[", 0, "]:", "Taking cached result"],
      Editable->False]], "Print",
  CellLabel->"From In[54]:="],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"Debug[\"\>", "\[InvisibleSpace]", "0", 
        "\[InvisibleSpace]", "\<\"]:\"\>", 
        "\[InvisibleSpace]", "\<\"Leave Level \"\>", "\[InvisibleSpace]", "1",
         "\[InvisibleSpace]", "\<\" Call \"\>", "\[InvisibleSpace]", 
        TagBox[\(MrvLimitInf[\[ExponentialE]\^x, x, 
              Debug \[Rule] 1] \[Equal] \[Infinity]\),
          HoldForm]}],
      SequenceForm[ "Debug[", 0, "]:", "Leave Level ", 1, " Call ", 
        HoldForm[ 
          Equal[ 
            MrvLimitInf[ 
              power[ E, x], x, Debug -> 1], 
            DirectedInfinity[ 1]]]],
      Editable->False]], "Print",
  CellLabel->"From In[54]:="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Ausgabesteuerung", "Subsubsection"],

Cell[TextData[{
  "Da die Ausgabe von Funktionsteilen und die Debugausgabe sehr umfangreich \
sein kann, ist es u.U. sinnvoll, solche Ausgaben zu filtern. Mit der Variable \
",
  StyleBox["$OutputProcessor",
    FontFamily->"Courier New"],
  StyleBox[" kann jede Debugausgabe und jede Meldungsausgabe nachbearbeitet \
werden:",
    FontFamily->"Times New Roman"]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(f = \[ExponentialE]\^\(\[ExponentialE]\^\(h - x\) + h - x\/\(1 + \
h\)\)\  /. h -> \ 
            1\/\(1 + \[ExponentialE]\^\(-x\)\);\)\), "\[IndentingNewLine]", 
    \(\($OutputProcessor = \((FromInternal[#, 
                x] /. {1\/\(1 + \[ExponentialE]\^\(-x\)\) \[Rule] 
                  h} &)\);\)\), "\[IndentingNewLine]", 
    \(\(MrvLimit[f, x \[Rule] \[Infinity], Debug \[Rule] 1, 
        ClearCache \[Rule] True];\)\), "\[IndentingNewLine]", 
    \(\($OutputProcessor = Identity;\)\)}], "Input",
  CellLabel->"In[40]:="],

Cell[BoxData[
    TagBox[
      AdjustmentBox[
        InterpretationBox[
          
          RowBox[{"\<\"Enter Level \"\>", "\[InvisibleSpace]", "1", 
            "\[InvisibleSpace]", "\<\" Call \"\>", "\[InvisibleSpace]", 
            
            TagBox[\(MrvLimitInf[\[ExponentialE]\^\(\[ExponentialE]\^\(\(-x\) \
+ h\) + h - x\/\(1 + h\)\), x, Debug \[Rule] 1]\),
              HoldForm]}],
          SequenceForm[ "Enter Level ", 1, " Call ", 
            HoldForm[ 
              MrvLimitInf[ 
                Power[ E, 
                  Plus[ 
                    Power[ E, 
                      Plus[ 
                        Times[ -1, x], h]], h, 
                    Times[ -1, x, 
                      Power[ 
                        Plus[ 1, h], -1]]]], x, Debug -> 1]]],
          Editable->False],
        BoxMargins->{{0, 0}, {0, 0}}],
      DisplayForm]], "Print",
  CellLabel->"From In[40]:="],

Cell[BoxData[
    TagBox[
      AdjustmentBox[
        InterpretationBox[\("Calculating limit of "\[InvisibleSpace]\
\[ExponentialE]\^\(\[ExponentialE]\^\(h - x\) + h - x\/\(1 + h\)\)\),
          SequenceForm[ "Calculating limit of ", 
            Power[ E, 
              Plus[ 
                Power[ E, 
                  Plus[ h, 
                    Times[ -1, x]]], h, 
                Times[ -1, 
                  Power[ 
                    Plus[ 1, h], -1], x]]]],
          Editable->False],
        BoxMargins->{{0, 0}, {0, 0}}],
      DisplayForm]], "Print",
  CellLabel->"From In[40]:="],

Cell[BoxData[
    TagBox[
      AdjustmentBox[
        InterpretationBox[\("Calculating Mrv set of "\[InvisibleSpace]\
\[ExponentialE]\^\(\[ExponentialE]\^\(h - x\) + h - x\/\(1 + h\)\)\),
          SequenceForm[ "Calculating Mrv set of ", 
            Power[ E, 
              Plus[ 
                Power[ E, 
                  Plus[ h, 
                    Times[ -1, x]]], h, 
                Times[ -1, 
                  Power[ 
                    Plus[ 1, h], -1], x]]]],
          Editable->False],
        BoxMargins->{{0, 0}, {0, 0}}],
      DisplayForm]], "Print",
  CellLabel->"From In[40]:="],

Cell[BoxData[
    TagBox[
      AdjustmentBox[
        InterpretationBox[\("\[CapitalOmega]="\[InvisibleSpace]{MrvF[\
\[ExponentialE]\^\(-x\), 5, 0], MrvF[\[ExponentialE]\^\(h - x\), 15, 0], 
              MrvF[\[ExponentialE]\^\(\[ExponentialE]\^\(h - x\) + h - x\/\(1 \
+ h\)\), 43, 0]}\),
          SequenceForm[ "\[CapitalOmega]=", {
            MrvF[ 
              Power[ E, 
                Times[ -1, x]], 5, 0], 
            MrvF[ 
              Power[ E, 
                Plus[ h, 
                  Times[ -1, x]]], 15, 0], 
            MrvF[ 
              Power[ E, 
                Plus[ 
                  Power[ E, 
                    Plus[ h, 
                      Times[ -1, x]]], h, 
                  Times[ -1, 
                    Power[ 
                      Plus[ 1, h], -1], x]]], 43, 0]}],
          Editable->False],
        BoxMargins->{{0, 0}, {0, 0}}],
      DisplayForm]], "Print",
  CellLabel->"From In[40]:="],

Cell[BoxData[
    TagBox[
      AdjustmentBox[
        InterpretationBox[\("\[Omega]="\[InvisibleSpace]\[ExponentialE]\^\(-x\
\)\),
          SequenceForm[ "\[Omega]=", 
            Power[ E, 
              Times[ -1, x]]],
          Editable->False],
        BoxMargins->{{0, 0}, {0, 0}}],
      DisplayForm]], "Print",
  CellLabel->"From In[40]:="],

Cell[BoxData[
    TagBox[
      AdjustmentBox[
        InterpretationBox[\("Prepare to rewrite g="\[InvisibleSpace]\
\[ExponentialE]\^\(\[ExponentialE]\^\(h - x\) + h - x\/\(1 + h\)\)\
\[InvisibleSpace]" to A*\[Omega]^c"\),
          SequenceForm[ "Prepare to rewrite g=", 
            Power[ E, 
              Plus[ 
                Power[ E, 
                  Plus[ h, 
                    Times[ -1, x]]], h, 
                Times[ -1, 
                  Power[ 
                    Plus[ 1, h], -1], x]]], " to A*\[Omega]^c"],
          Editable->False],
        BoxMargins->{{0, 0}, {0, 0}}],
      DisplayForm]], "Print",
  CellLabel->"From In[40]:="],

Cell[BoxData[
    TagBox[
      AdjustmentBox[
        InterpretationBox[\("c="\[InvisibleSpace]1\/2\[InvisibleSpace]" A="\
\[InvisibleSpace]\[ExponentialE]\^\(\[ExponentialE]\^\(h - x\) + h + x\/2 - x\
\/\(1 + h\)\)\),
          SequenceForm[ "c=", 
            Rational[ 1, 2], " A=", 
            Power[ E, 
              Plus[ 
                Power[ E, 
                  Plus[ h, 
                    Times[ -1, x]]], h, 
                Times[ 
                  Rational[ 1, 2], x], 
                Times[ -1, 
                  Power[ 
                    Plus[ 1, h], -1], x]]]],
          Editable->False],
        BoxMargins->{{0, 0}, {0, 0}}],
      DisplayForm]], "Print",
  CellLabel->"From In[40]:="],

Cell[BoxData[
    TagBox[
      AdjustmentBox[
        InterpretationBox[\("Rewriting "\[InvisibleSpace]\[ExponentialE]\^\(\
\[ExponentialE]\^\(h - x\) + h - x\/\(1 + h\)\)\[InvisibleSpace]"\[Rule]"\
\[InvisibleSpace]\(\[ExponentialE]\^\(\[ExponentialE]\^\(h - x\) + h + x\/2 - \
x\/\(1 + h\)\)\ \@\[Omega]\)\[InvisibleSpace]"\n"\[InvisibleSpace]"f="\
\[InvisibleSpace]\(\[ExponentialE]\^\(\[ExponentialE]\^\(h - x\) + h + x\/2 - \
x\/\(1 + h\)\)\ \@\[Omega]\)\),
          SequenceForm[ "Rewriting ", 
            Power[ E, 
              Plus[ 
                Power[ E, 
                  Plus[ h, 
                    Times[ -1, x]]], h, 
                Times[ -1, 
                  Power[ 
                    Plus[ 1, h], -1], x]]], "\[Rule]", 
            Times[ 
              Power[ E, 
                Plus[ 
                  Power[ E, 
                    Plus[ h, 
                      Times[ -1, x]]], h, 
                  Times[ 
                    Rational[ 1, 2], x], 
                  Times[ -1, 
                    Power[ 
                      Plus[ 1, h], -1], x]]], 
              Power[ \[Omega], 
                Rational[ 1, 2]]], "\n", "f=", 
            Times[ 
              Power[ E, 
                Plus[ 
                  Power[ E, 
                    Plus[ h, 
                      Times[ -1, x]]], h, 
                  Times[ 
                    Rational[ 1, 2], x], 
                  Times[ -1, 
                    Power[ 
                      Plus[ 1, h], -1], x]]], 
              Power[ \[Omega], 
                Rational[ 1, 2]]]],
          Editable->False],
        BoxMargins->{{0, 0}, {0, 0}}],
      DisplayForm]], "Print",
  CellLabel->"From In[40]:="],

Cell[BoxData[
    TagBox[
      AdjustmentBox[
        InterpretationBox[\("Prepare to rewrite g="\[InvisibleSpace]\
\[ExponentialE]\^\(h - x\)\[InvisibleSpace]" to A*\[Omega]^c"\),
          SequenceForm[ "Prepare to rewrite g=", 
            Power[ E, 
              Plus[ h, 
                Times[ -1, x]]], " to A*\[Omega]^c"],
          Editable->False],
        BoxMargins->{{0, 0}, {0, 0}}],
      DisplayForm]], "Print",
  CellLabel->"From In[40]:="],

Cell[BoxData[
    TagBox[
      AdjustmentBox[
        InterpretationBox[\("c="\[InvisibleSpace]1\[InvisibleSpace]" A="\
\[InvisibleSpace]\[ExponentialE]\^h\),
          SequenceForm[ "c=", 1, " A=", 
            Power[ E, h]],
          Editable->False],
        BoxMargins->{{0, 0}, {0, 0}}],
      DisplayForm]], "Print",
  CellLabel->"From In[40]:="],

Cell[BoxData[
    TagBox[
      AdjustmentBox[
        InterpretationBox[\("Rewriting "\[InvisibleSpace]\[ExponentialE]\^\(h \
- x\)\[InvisibleSpace]"\[Rule]"\[InvisibleSpace]\(\[ExponentialE]\^h\ \
\[Omega]\)\[InvisibleSpace]"\n"\[InvisibleSpace]"f="\[InvisibleSpace]\(\
\[ExponentialE]\^\(h + x\/2 - x\/\(1 + h\) + \[ExponentialE]\^h\ \[Omega]\)\ \
\@\[Omega]\)\),
          SequenceForm[ "Rewriting ", 
            Power[ E, 
              Plus[ h, 
                Times[ -1, x]]], "\[Rule]", 
            Times[ 
              Power[ E, h], \[Omega]], "\n", "f=", 
            Times[ 
              Power[ E, 
                Plus[ h, 
                  Times[ 
                    Rational[ 1, 2], x], 
                  Times[ -1, 
                    Power[ 
                      Plus[ 1, h], -1], x], 
                  Times[ 
                    Power[ E, h], \[Omega]]]], 
              Power[ \[Omega], 
                Rational[ 1, 2]]]],
          Editable->False],
        BoxMargins->{{0, 0}, {0, 0}}],
      DisplayForm]], "Print",
  CellLabel->"From In[40]:="],

Cell[BoxData[
    TagBox[
      AdjustmentBox[
        InterpretationBox[\("Prepare to rewrite g="\[InvisibleSpace]\
\[ExponentialE]\^\(-x\)\[InvisibleSpace]" to A*\[Omega]^c"\),
          SequenceForm[ "Prepare to rewrite g=", 
            Power[ E, 
              Times[ -1, x]], " to A*\[Omega]^c"],
          Editable->False],
        BoxMargins->{{0, 0}, {0, 0}}],
      DisplayForm]], "Print",
  CellLabel->"From In[40]:="],

Cell[BoxData[
    TagBox[
      AdjustmentBox[
        InterpretationBox[\("c="\[InvisibleSpace]1\[InvisibleSpace]" A="\
\[InvisibleSpace]1\),
          SequenceForm[ "c=", 1, " A=", 1],
          Editable->False],
        BoxMargins->{{0, 0}, {0, 0}}],
      DisplayForm]], "Print",
  CellLabel->"From In[40]:="],

Cell[BoxData[
    TagBox[
      AdjustmentBox[
        InterpretationBox[\("Rewriting \
"\[InvisibleSpace]\[ExponentialE]\^\(-x\)\[InvisibleSpace]"\[Rule]"\
\[InvisibleSpace]\[Omega]\[InvisibleSpace]"\n"\[InvisibleSpace]"f="\
\[InvisibleSpace]\(\[ExponentialE]\^\(x\/2 + \[ExponentialE]\^\(1\/\(1 + \
\[Omega]\)\)\ \[Omega] + 1\/\(1 + \[Omega]\) - x\/\(1 + 1\/\(1 + \[Omega]\)\)\
\)\ \@\[Omega]\)\),
          SequenceForm[ "Rewriting ", 
            Power[ E, 
              Times[ -1, x]], "\[Rule]", \[Omega], "\n", "f=", 
            Times[ 
              Power[ E, 
                Plus[ 
                  Times[ 
                    Rational[ 1, 2], x], 
                  Times[ 
                    Power[ E, 
                      Power[ 
                        Plus[ 1, \[Omega]], -1]], \[Omega]], 
                  Power[ 
                    Plus[ 1, \[Omega]], -1], 
                  Times[ -1, x, 
                    Power[ 
                      Plus[ 1, 
                        Power[ 
                          Plus[ 1, \[Omega]], -1]], -1]]]], 
              Power[ \[Omega], 
                Rational[ 1, 2]]]],
          Editable->False],
        BoxMargins->{{0, 0}, {0, 0}}],
      DisplayForm]], "Print",
  CellLabel->"From In[40]:="],

Cell[BoxData[
    TagBox[
      AdjustmentBox[
        InterpretationBox[\("Calculating power series: f="\[InvisibleSpace]\(\
\[ExponentialE]\^\(x\/2 + \[ExponentialE]\^\(1\/\(1 + \[Omega]\)\)\ \[Omega] \
+ 1\/\(1 + \[Omega]\) - x\/\(1 + 1\/\(1 + \[Omega]\)\)\)\ \@\[Omega]\)\),
          SequenceForm[ "Calculating power series: f=", 
            Times[ 
              Power[ E, 
                Plus[ 
                  Times[ 
                    Rational[ 1, 2], x], 
                  Times[ 
                    Power[ E, 
                      Power[ 
                        Plus[ 1, \[Omega]], -1]], \[Omega]], 
                  Power[ 
                    Plus[ 1, \[Omega]], -1], 
                  Times[ -1, x, 
                    Power[ 
                      Plus[ 1, 
                        Power[ 
                          Plus[ 1, \[Omega]], -1]], -1]]]], 
              Power[ \[Omega], 
                Rational[ 1, 2]]]],
          Editable->False],
        BoxMargins->{{0, 0}, {0, 0}}],
      DisplayForm]], "Print",
  CellLabel->"From In[40]:="],

Cell[BoxData[
    TagBox[
      AdjustmentBox[
        InterpretationBox[
          RowBox[{"\<\"Series expansion: \"\>", "\[InvisibleSpace]", 
            InterpretationBox[
              RowBox[{\(\[ExponentialE]\ \@\[Omega]\), "+", 
                InterpretationBox[\(O[\[Omega]]\^\(3/2\)\),
                  SeriesData[ \[Omega], 0, {}, 1, 3, 2],
                  Editable->False]}],
              SeriesData[ \[Omega], 0, {E}, 1, 3, 2],
              Editable->False]}],
          SequenceForm[ "Series expansion: ", 
            SeriesData[ \[Omega], 0, {E}, 1, 3, 2]],
          Editable->False],
        BoxMargins->{{0, 0}, {0, 0}}],
      DisplayForm]], "Print",
  CellLabel->"From In[40]:="],

Cell[BoxData[
    TagBox[
      AdjustmentBox[
        InterpretationBox[\("Dominant term: "\[InvisibleSpace]\(\
\[ExponentialE]\ \@\[Omega]\)\[InvisibleSpace]" , \[Omega]="\[InvisibleSpace]\
\[ExponentialE]\^\(-x\)\),
          SequenceForm[ "Dominant term: ", 
            Times[ E, 
              Power[ \[Omega], 
                Rational[ 1, 2]]], " , \[Omega]=", 
            Power[ E, 
              Times[ -1, x]]],
          Editable->False],
        BoxMargins->{{0, 0}, {0, 0}}],
      DisplayForm]], "Print",
  CellLabel->"From In[40]:="],

Cell[BoxData[
    TagBox[
      AdjustmentBox[
        InterpretationBox[\("Dominant asymptotic: "\[InvisibleSpace]\
\[ExponentialE]\[InvisibleSpace]\@\[ExponentialE]\^\(-x\)\),
          SequenceForm[ "Dominant asymptotic: ", E, 
            Power[ 
              Power[ E, 
                Times[ -1, x]], 
              Rational[ 1, 2]]],
          Editable->False],
        BoxMargins->{{0, 0}, {0, 0}}],
      DisplayForm]], "Print",
  CellLabel->"From In[40]:="],

Cell[BoxData[
    TagBox[
      AdjustmentBox[
        InterpretationBox[
          
          RowBox[{"\<\"Leave Level \"\>", "\[InvisibleSpace]", "1", 
            "\[InvisibleSpace]", "\<\" Call \"\>", "\[InvisibleSpace]", 
            
            TagBox[\(MrvLimitInf[\[ExponentialE]\^\(\[ExponentialE]\^\(\(-x\) \
+ h\) + h - x\/\(1 + h\)\), x, Debug \[Rule] 1] \[Equal] 0\),
              HoldForm]}],
          SequenceForm[ "Leave Level ", 1, " Call ", 
            HoldForm[ 
              Equal[ 
                MrvLimitInf[ 
                  Power[ E, 
                    Plus[ 
                      Power[ E, 
                        Plus[ 
                          Times[ -1, x], h]], h, 
                      Times[ -1, x, 
                        Power[ 
                          Plus[ 1, h], -1]]]], x, Debug -> 1], 0]]],
          Editable->False],
        BoxMargins->{{0, 0}, {0, 0}}],
      DisplayForm]], "Print",
  CellLabel->"From In[40]:="]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.0 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 887}},
WindowToolbars->{},
WindowSize->{1016, 443},
WindowMargins->{{80, Automatic}, {Automatic, -17}},
Magnification->1.25,
StyleDefinitions -> "ArticleModern.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 37, 0, 108, "Title"],
Cell[1816, 55, 443, 7, 73, "Text"],

Cell[CellGroupData[{
Cell[2284, 66, 35, 0, 79, "Section"],
Cell[2322, 68, 451, 16, 52, "Text"],

Cell[CellGroupData[{
Cell[2798, 88, 79, 2, 53, "Input"],
Cell[2880, 92, 233, 4, 111, "Print"]
}, Open  ]],
Cell[3128, 99, 98, 2, 31, "Text"],

Cell[CellGroupData[{
Cell[3251, 105, 112, 2, 53, "Input"],
Cell[3366, 109, 233, 4, 111, "Print"]
}, Open  ]],
Cell[3614, 116, 144, 3, 31, "Text"],
Cell[3761, 121, 154, 3, 74, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3952, 129, 49, 0, 79, "Section"],
Cell[4004, 131, 207, 6, 31, "Text"],

Cell[CellGroupData[{
Cell[4236, 141, 169, 3, 96, "Input"],
Cell[4408, 146, 59, 2, 53, "Output"]
}, Open  ]],
Cell[4482, 151, 138, 3, 31, "Text"],

Cell[CellGroupData[{
Cell[4645, 158, 107, 2, 53, "Input"],
Cell[4755, 162, 69, 2, 53, "Output"]
}, Open  ]],
Cell[4839, 167, 360, 8, 52, "Text"],

Cell[CellGroupData[{
Cell[5224, 179, 81, 2, 53, "Input"],
Cell[5308, 183, 89, 2, 53, "Output"]
}, Open  ]],
Cell[5412, 188, 171, 4, 31, "Text"],

Cell[CellGroupData[{
Cell[5608, 196, 88, 2, 53, "Input"],
Cell[5699, 200, 69, 2, 53, "Output"]
}, Open  ]],
Cell[5783, 205, 286, 7, 52, "Text"],

Cell[CellGroupData[{
Cell[6094, 216, 88, 2, 53, "Input"],
Cell[6185, 220, 220, 4, 20, "Message"],
Cell[6408, 226, 114, 3, 67, "Output"]
}, Open  ]],
Cell[6537, 232, 239, 6, 31, "Text"],

Cell[CellGroupData[{
Cell[6801, 242, 324, 6, 96, "Input"],
Cell[7128, 250, 59, 2, 53, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7224, 257, 89, 2, 53, "Input"],
Cell[7316, 261, 282, 5, 72, "Output"]
}, Open  ]],
Cell[7613, 269, 399, 11, 52, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8049, 285, 44, 0, 79, "Section"],
Cell[8096, 287, 225, 5, 31, "Text"],

Cell[CellGroupData[{
Cell[8346, 296, 38, 0, 52, "Subsubsection"],
Cell[8387, 298, 6345, 200, 391, "Text"],

Cell[CellGroupData[{
Cell[14757, 502, 338, 8, 87, "Input"],
Cell[15098, 512, 254, 5, 59, "Output"]
}, Open  ]],
Cell[15367, 520, 516, 14, 75, "Text"],

Cell[CellGroupData[{
Cell[15908, 538, 82, 2, 53, "Input"],
Cell[15993, 542, 230, 5, 67, "Output"]
}, Open  ]],
Cell[16238, 550, 117, 3, 31, "Text"],

Cell[CellGroupData[{
Cell[16380, 557, 86, 2, 53, "Input"],
Cell[16469, 561, 106, 2, 53, "Output"]
}, Open  ]],
Cell[16590, 566, 76, 0, 31, "Text"],

Cell[CellGroupData[{
Cell[16691, 570, 100, 2, 53, "Input"],
Cell[16794, 574, 82, 2, 53, "Output"]
}, Open  ]],
Cell[16891, 579, 104, 1, 31, "Text"],

Cell[CellGroupData[{
Cell[17020, 584, 95, 2, 53, "Input"],
Cell[17118, 588, 60, 2, 53, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[17227, 596, 39, 0, 52, "Subsubsection"],
Cell[17269, 598, 553, 11, 73, "Text"],

Cell[CellGroupData[{
Cell[17847, 613, 198, 4, 74, "Input"],
Cell[18048, 619, 70, 2, 53, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[18155, 626, 208, 5, 74, "Input"],
Cell[18366, 633, 70, 2, 53, "Output"]
}, Open  ]],
Cell[18451, 638, 254, 6, 52, "Text"],

Cell[CellGroupData[{
Cell[18730, 648, 148, 3, 53, "Input"],
Cell[18881, 653, 60, 2, 53, "Output"]
}, Open  ]],
Cell[18956, 658, 102, 2, 53, "Input"],
Cell[19061, 662, 465, 13, 52, "Text"],

Cell[CellGroupData[{
Cell[19551, 679, 81, 2, 53, "Input"],
Cell[19635, 683, 105, 2, 53, "Output"]
}, Open  ]],
Cell[19755, 688, 353, 9, 52, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[20145, 702, 43, 0, 52, "Subsubsection"],
Cell[20191, 704, 509, 16, 52, "Text"],

Cell[CellGroupData[{
Cell[20725, 724, 143, 3, 53, "Input"],
Cell[20871, 729, 668, 18, 48, "Print"],
Cell[21542, 749, 342, 10, 48, "Print"],
Cell[21887, 761, 346, 10, 48, "Print"],
Cell[22236, 773, 420, 12, 48, "Print"],
Cell[22659, 787, 316, 9, 48, "Print"],
Cell[22978, 798, 424, 11, 48, "Print"],
Cell[23405, 811, 397, 10, 48, "Print"],
Cell[23805, 823, 319, 9, 48, "Print"],
Cell[24127, 834, 539, 13, 100, "Print"],
Cell[24669, 849, 357, 10, 62, "Print"],
Cell[25029, 861, 686, 17, 62, "Print"],
Cell[25718, 880, 472, 12, 62, "Print"],
Cell[26193, 894, 427, 12, 62, "Print"],
Cell[26623, 908, 757, 20, 48, "Print"],
Cell[27383, 930, 70, 2, 53, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[27514, 939, 34, 0, 79, "Section"],

Cell[CellGroupData[{
Cell[27573, 943, 50, 0, 52, "Subsubsection"],
Cell[27626, 945, 1278, 33, 391, "Text"],

Cell[CellGroupData[{
Cell[28929, 982, 83, 2, 53, "Input"],
Cell[29015, 986, 98, 2, 53, "Output"]
}, Open  ]],
Cell[29128, 991, 783, 30, 52, "Text"],

Cell[CellGroupData[{
Cell[29936, 1025, 89, 2, 53, "Input"],
Cell[30028, 1029, 88, 2, 53, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[30153, 1036, 78, 2, 53, "Input"],
Cell[30234, 1040, 88, 2, 53, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[30359, 1047, 76, 2, 53, "Input"],
Cell[30438, 1051, 77, 2, 53, "Output"]
}, Open  ]],
Cell[30530, 1056, 175, 5, 31, "Text"],

Cell[CellGroupData[{
Cell[30730, 1065, 79, 2, 53, "Input"],
Cell[30812, 1069, 175, 3, 20, "Message"],
Cell[30990, 1074, 104, 3, 53, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[31155, 1084, 45, 0, 79, "Section"],

Cell[CellGroupData[{
Cell[31225, 1088, 37, 0, 52, "Subsubsection"],
Cell[31265, 1090, 764, 16, 94, "Text"],

Cell[CellGroupData[{
Cell[32054, 1110, 135, 3, 62, "Input"],
Cell[32192, 1115, 190, 4, 37, "Message"],
Cell[32385, 1121, 162, 4, 62, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[32584, 1130, 827, 16, 297, "Input"],
Cell[33414, 1148, 74, 2, 53, "Output"]
}, Open  ]],
Cell[33503, 1153, 215, 6, 31, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[33755, 1164, 34, 0, 52, "Subsubsection"],
Cell[33792, 1166, 2315, 52, 451, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[36144, 1223, 37, 0, 52, "Subsubsection"],
Cell[36184, 1225, 271, 8, 31, "Text"],

Cell[CellGroupData[{
Cell[36480, 1237, 381, 8, 116, "Input"],
Cell[36864, 1247, 603, 13, 48, "Print"],
Cell[37470, 1262, 257, 5, 48, "Print"],
Cell[37730, 1269, 697, 16, 48, "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[38476, 1291, 41, 0, 52, "Subsubsection"],
Cell[38520, 1293, 374, 9, 52, "Text"],

Cell[CellGroupData[{
Cell[38919, 1306, 557, 10, 148, "Input"],
Cell[39479, 1318, 917, 25, 56, "Print"],
Cell[40399, 1345, 602, 17, 54, "Print"],
Cell[41004, 1364, 606, 17, 54, "Print"],
Cell[41613, 1383, 945, 27, 56, "Print"],
Cell[42561, 1412, 350, 11, 48, "Print"],
Cell[42914, 1425, 659, 18, 54, "Print"],
Cell[43576, 1445, 717, 21, 62, "Print"],
Cell[44296, 1468, 1713, 47, 82, "Print"],
Cell[46012, 1517, 459, 12, 48, "Print"],
Cell[46474, 1531, 354, 10, 48, "Print"],
Cell[46831, 1543, 1080, 29, 75, "Print"],
Cell[47914, 1574, 429, 11, 48, "Print"],
Cell[48346, 1587, 313, 9, 48, "Print"],
Cell[48662, 1598, 1263, 33, 98, "Print"],
Cell[49928, 1633, 1073, 28, 74, "Print"],
Cell[51004, 1663, 705, 17, 50, "Print"],
Cell[51712, 1682, 550, 15, 50, "Print"],
Cell[52265, 1699, 468, 13, 50, "Print"],
Cell[52736, 1714, 972, 26, 56, "Print"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

