(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     52223,       1730]*)
(*NotebookOutlinePosition[     52949,       1755]*)
(*  CellTagsIndexPosition[     52905,       1751]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["The Package MrvLimit", "Title"],

Cell["\<\
The Mathematica package MrvLimit is a package for real-valued limit \
calculation, especially for exponential and logarithmic functions. The \
package was developed as part of the diploma thesis \"Automatische Berechnung \
von Grenzwerten und Implementierung in Mathematica\" by Udo Richter and is \
based on the dissertation \"On Computing Limits in a Symbolic Manipulation \
System\" by Dominik Gruntz.\
\>", "Text"],

Cell[CellGroupData[{

Cell["Loading the package", "Section"],

Cell[TextData[{
  "The package gets loaded like every other ",
  "Mathematica",
  " package with ",
  StyleBox["Needs",
    FontFamily->"Courier New"],
  " or ",
  StyleBox["Get",
    FontFamily->"Courier New"],
  ".\nIs the file ",
  StyleBox["MrvLimit.m",
    FontFamily->"Courier New"],
  " in a folder of the ",
  "Mathematica",
  " search path ",
  StyleBox["$Path",
    FontFamily->"Courier New"],
  ", the package can be loaded directly:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Needs["\<MrvLimit`\>"]\)], "Input",
  CellLabel->"In[1]:="],

Cell[BoxData[
    \("MrvLimit v1.0 \[Copyright] 2005 by Udo Richter\n mail: \
udo_richter(at)gmx.de\n web: http://urichter.cjb.net/MrvLimit\n Released \
under the GNU General Public License."\)], "Print",
  CellLabel->"From In[3]:="]
}, Open  ]],

Cell["\<\
In other cases, you have to specify the full path to the file:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Needs["\<MrvLimit`\>", "\<Path/To/The/File/MrvLimit.m\>"]\)], "Input",
  CellLabel->"In[1]:="],

Cell[BoxData[
    \("MrvLimit v1.0 \[Copyright] 2005 by Udo Richter\n mail: \
udo_richter(at)gmx.de\n web: http://urichter.cjb.net/MrvLimit\n Released \
under the GNU General Public License."\)], "Print",
  CellLabel->"From In[1]:="]
}, Open  ]],

Cell["\<\
If the packet is only needed as part of another packet, it can be loaded \
silently:\
\>", "Text"],

Cell[BoxData[{
    \(\(MrvLimit`MrvLimitLoadSilent = True;\)\), "\[IndentingNewLine]", 
    \(Needs["\<MrvLimit`\>"]\)}], "Input",
  CellLabel->"In[1]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell["Simple limit calculations", "Section"],

Cell[TextData[{
  "Simple limit calculations can be done the same way as with Mathematicas ",
  StyleBox["Limit",
    FontFamily->"Courier New"],
  " function:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(f = x\^2\/\(\((x + 1)\) \((x - 1)\)\);\)\), "\[IndentingNewLine]", 
    \(MrvLimit[f, x \[Rule] \[Infinity]]\)}], "Input",
  CellLabel->"In[2]:="],

Cell[BoxData[
    \(1\)], "Output",
  CellLabel->"Out[3]="]
}, Open  ]],

Cell["\<\
If no unique limit exists, the direction of approach can be specified:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MrvLimit[f, x \[Rule] 1, Direction \[Rule] \(-1\)]\)], "Input",
  CellLabel->"In[4]:="],

Cell[BoxData[
    \(\[Infinity]\)], "Output",
  CellLabel->"Out[4]="]
}, Open  ]],

Cell[TextData[{
  "For tthis, -1 means approach from above, +1 means approach from below, and \
0 means two-sided approach. If ",
  StyleBox["MrvLimit",
    FontFamily->"Courier New"],
  " finds a discontinuity in two-sided mode, both limits will be returned as \
a list:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MrvLimit[f, x \[Rule] 1]\)], "Input",
  CellLabel->"In[5]:="],

Cell[BoxData[
    \({\(-\[Infinity]\), \[Infinity]}\)], "Output",
  CellLabel->"Out[5]="]
}, Open  ]],

Cell["\<\
As optically nice variant, the direction of approach can be specified by \
superscripted + or - added to the limit point:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MrvLimit[f, x \[Rule] \(1\^+\)]\)], "Input",
  CellLabel->"In[6]:="],

Cell[BoxData[
    \(\[Infinity]\)], "Output",
  CellLabel->"Out[6]="]
}, Open  ]],

Cell[TextData[{
  "If ",
  StyleBox["MrvLimit",
    FontFamily->"Courier New"],
  " cannot solve the limit, a warning message is issued, and the limit call \
will be returned un-evaluated:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MrvLimit[Sin[1/x], x \[Rule] 0]\)], "Input",
  CellLabel->"In[7]:="],

Cell[BoxData[
    \(MrvLimit::"UnsupportedArgument" \(\(:\)\(\ \)\) 
      "MrvLimit does not support \!\(Sin[x]\) for \!\(x \[Rule] \
\[Infinity]\), appearing in \!\(Sin[x]\)"\)], "Message",
  CellLabel->"From In[7]:="],

Cell[BoxData[
    TagBox[\(MrvLimit[Sin[1\/x], x \[Rule] 0]\),
      HoldForm]], "Output",
  CellLabel->"Out[7]="]
}, Open  ]],

Cell[TextData[{
  "The speciality of the ",
  StyleBox["MrvLimit",
    FontFamily->"Courier New"],
  " algorithm are functions with nested exponential- and logarithmic \
functions:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(f = \[ExponentialE]\^x\ \((\(-\[ExponentialE]\^\(1\/x - \
\[ExponentialE]\^\(-\[ExponentialE]\^x\)\)\) + \[ExponentialE]\^\(\
\[ExponentialE]\^\(-x\) + \[ExponentialE]\^\(-x\^2\) + 1\/x\))\);\)\), "\
\[IndentingNewLine]", 
    \(MrvLimit[f, x \[Rule] \[Infinity]]\)}], "Input",
  CellLabel->"In[8]:="],

Cell[BoxData[
    \(1\)], "Output",
  CellLabel->"Out[9]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Limit[f, x \[Rule] \[Infinity]]\)], "Input",
  CellLabel->"In[10]:="],

Cell[BoxData[
    \(Limit[\[ExponentialE]\^x\ \((\(-\[ExponentialE]\^\(\(-\[ExponentialE]\^\
\(-\[ExponentialE]\^x\)\) + 1\/x\)\) + \
\[ExponentialE]\^\(\[ExponentialE]\^\(-x\) + \[ExponentialE]\^\(-x\^2\) + \
1\/x\))\), x \[Rule] \[Infinity]]\)], "Output",
  CellLabel->"Out[10]="]
}, Open  ]],

Cell[TextData[{
  StyleBox["MrvLimit",
    FontFamily->"Courier New"],
  " supports the basic operations +, -, *, /, power and root, and the \
functions ",
  StyleBox["Log, Gamma, LogGamma, PolyGamma, Sin, Cos, Tan, ArcSin, ArcCos, \
ArcTan, Sec, Csc, Cot, ArcSec, ArcCsc",
    FontFamily->"Courier New"],
  " and ",
  StyleBox["ArcCot.",
    FontFamily->"Courier New"]
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Advanced options", "Section"],

Cell[TextData[{
  StyleBox["MrvLimit",
    FontFamily->"Courier New"],
  " supports some advanced options. These options can be added in any order."
}], "Text"],

Cell[CellGroupData[{

Cell["Output format", "Subsubsection"],

Cell[TextData[{
  "Using ",
  StyleBox["Output\[Rule]Limit",
    FontFamily->"Courier New"],
  ", ",
  StyleBox["Output\[Rule]LeadTerm",
    FontFamily->"Courier New"],
  " and ",
  StyleBox["Output\[Rule]SignedZero",
    FontFamily->"Courier New"],
  ", the output format of ",
  StyleBox["MrvLimit",
    FontFamily->"Courier New"],
  " can be modified. ",
  StyleBox["Output\[Rule]Limit",
    FontFamily->"Courier New"],
  " is the default format.\n\n",
  StyleBox["Limit[",
    FontFamily->"Courier New"],
  StyleBox["f",
    FontFamily->"Courier New",
    FontSlant->"Italic"],
  StyleBox[",",
    FontFamily->"Courier New"],
  StyleBox["x",
    FontFamily->"Courier New",
    FontSlant->"Italic"],
  StyleBox["\[Rule]",
    FontFamily->"Courier New"],
  StyleBox["lim",
    FontFamily->"Courier New",
    FontSlant->"Italic"],
  StyleBox[", Output\[Rule]SignedZero]",
    FontFamily->"Courier New"],
  " returns the limit result as usual as long as the limit is not 0. If the \
limit is 0, either",
  StyleBox[" ",
    FontFamily->"Times New Roman"],
  StyleBox["Zero",
    FontFamily->"Courier New"],
  StyleBox[" or ",
    FontFamily->"Times New Roman"],
  StyleBox["-Zero",
    FontFamily->"Courier New"],
  StyleBox[" will be returned, depending on whether the function is positive \
or negative in an environment of the limiting point.\n",
    FontFamily->"Times New Roman"],
  "\n",
  StyleBox["Limit[",
    FontFamily->"Courier New"],
  StyleBox["f",
    FontFamily->"Courier New",
    FontSlant->"Italic"],
  StyleBox[",",
    FontFamily->"Courier New"],
  StyleBox["x",
    FontFamily->"Courier New",
    FontSlant->"Italic"],
  StyleBox["\[Rule]",
    FontFamily->"Courier New"],
  StyleBox["lim",
    FontFamily->"Courier New",
    FontSlant->"Italic"],
  StyleBox[", Output\[Rule]LeadTerm]",
    FontFamily->"Courier New"],
  StyleBox[" returns an asymptotic function that was calculated while \
calculating the limit. The output has this special format:",
    FontFamily->"Times New Roman"],
  "\n",
  StyleBox["LeadTerm[",
    FontFamily->"Courier New"],
  StyleBox["const",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[",{pwr[",
    FontFamily->"Courier New"],
  Cell[BoxData[
      \(TraditionalForm\`base\_1\)],
    FontSlant->"Italic"],
  StyleBox[",",
    FontFamily->"Courier New"],
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["exp",
            FontSlant->"Italic"], "1"], TraditionalForm]]],
  StyleBox["],pwr[",
    FontFamily->"Courier New"],
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["base",
            FontSlant->"Italic"], "2"], TraditionalForm]]],
  StyleBox[",",
    FontFamily->"Courier New"],
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["exp",
            FontSlant->"Italic"], "2"], TraditionalForm]]],
  StyleBox["],...,pwr[",
    FontFamily->"Courier New"],
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["base",
            FontSlant->"Italic"], "n"], TraditionalForm]]],
  StyleBox[",",
    FontFamily->"Courier New"],
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["exp",
            FontSlant->"Italic"], "n"], TraditionalForm]]],
  StyleBox["]}]\n",
    FontFamily->"Courier New"],
  StyleBox["const",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[" is the constant part of the function that does not depend on x,",
    
    FontFamily->"Times New Roman"],
  StyleBox["\n",
    FontFamily->"Courier New"],
  Cell[BoxData[
      \(TraditionalForm\`base\_i\)]],
  " are exponential base functions,\n",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["exp",
            FontSlant->"Italic"], "i"], TraditionalForm]]],
  " are the real-valued constant exponents, that represent the order, in \
which their base functions appear.\nThe returned terms are in internal \
format, to protect their special structure. By applying the function ",
  StyleBox["FromInternal[",
    FontFamily->"Courier New"],
  StyleBox["f",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[",",
    FontFamily->"Courier New"],
  StyleBox["x",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier New"],
  ", the general ",
  "Mathematica format can be calculated. More about this internal format in \
the chapter about helper functions.",
  "\nAll base functions are exponenetial functions, are positive, and for ",
  StyleBox["x",
    FontFamily->"Courier New",
    FontSlant->"Italic"],
  StyleBox["\[Rule]",
    FontFamily->"Courier New"],
  StyleBox["lim",
    FontFamily->"Courier New",
    FontSlant->"Italic"],
  " (",
  Cell[BoxData[
      \(TraditionalForm\`x > 0\)]],
  ") they have the limit 0.\nThe base functions are ordered by the falling \
order of growth, and the first function with ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[\(exp\_i\),
            FontSlant->"Italic"], "\[NotEqual]", "0"}], TraditionalForm]]],
  " is dominant and determines the growth behaviour of the function.\nThe \
asymptotic is the function",
  StyleBox[" ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            RowBox[{
              StyleBox["const",
                FontSlant->"Italic"], 
              StyleBox["*",
                FontSlant->"Plain"], 
              StyleBox[
                SuperscriptBox[
                  SubscriptBox["base", 
                    StyleBox["1",
                      FontSlant->"Plain"]], 
                  SubscriptBox["exp", 
                    StyleBox["1",
                      FontSlant->"Plain"]]],
                FontSlant->"Italic"], "*", 
              StyleBox[
                SuperscriptBox[
                  SubscriptBox["base", 
                    StyleBox["2",
                      FontSlant->"Plain"]], 
                  SubscriptBox["exp", 
                    StyleBox["2",
                      FontSlant->"Plain"]]],
                FontSlant->"Italic"], "*"}], "..."}], "*", 
          StyleBox[\(base\_n\^exp\_n\),
            FontSlant->"Italic"]}], TraditionalForm]]]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(f = \(-\[ExponentialE]\^\(1\/x - \
\[ExponentialE]\^\(-\[ExponentialE]\^x\)\)\) + \[ExponentialE]\^\(\
\[ExponentialE]\^\(-x\) + \[ExponentialE]\^\(-x\^2\) + 1\/x\);\)\), "\
\[IndentingNewLine]", 
    \(lt = 
      MrvLimit[f, x \[Rule] \[Infinity], Output \[Rule] LeadTerm]\)}], "Input",\

  CellLabel->"In[11]:="],

Cell[BoxData[
    \(LeadTerm[
      1, {pwr[\[ExponentialE]\^\(-\[ExponentialE]\^x\), 0], 
        pwr[\[ExponentialE]\^\(-x\^2\), 0], pwr[\[ExponentialE]\^\(-x\), 1], 
        pwr[\[ExponentialE]\^\(-Log[x]\), 0]}]\)], "Output",
  CellLabel->"Out[12]="]
}, Open  ]],

Cell[TextData[{
  "All terms except the ",
  Cell[BoxData[
      \(\[ExponentialE]\^\(-x\)\)]],
  " term are not really present, and dont affect the limiting behaviour.\nThe \
output is in MrvLimit internal format, and not in ",
  "Mathematica ",
  "format. By transforming back to ",
  "Mathematica ",
  "format, the term ",
  Cell[BoxData[
      \(\[ExponentialE]\^\(-Log[x]\)\)]],
  "gets simplified to ",
  Cell[BoxData[
      \(1\/x\)]],
  "again:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(lt = FromInternal[lt, x]\)], "Input",
  CellLabel->"In[13]:="],

Cell[BoxData[
    \(LeadTerm[
      1, {pwr[\[ExponentialE]\^\(-\[ExponentialE]\^x\), 0], 
        pwr[\[ExponentialE]\^\(-x\^2\), 0], pwr[\[ExponentialE]\^\(-x\), 1], 
        pwr[1\/x, 0]}]\)], "Output",
  CellLabel->"Out[13]="]
}, Open  ]],

Cell["\<\
By applying the proper power functions, all non-appearing base functions \
disappear:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(lt = lt /. pwr \[Rule] Power\)], "Input",
  CellLabel->"In[14]:="],

Cell[BoxData[
    \(LeadTerm[1, {1, 1, \[ExponentialE]\^\(-x\), 1}]\)], "Output",
  CellLabel->"Out[14]="]
}, Open  ]],

Cell["\<\
Multiplication of all terms results in the actual asyptitic function:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(lt = lt[\([1]\)]*Apply[Times, lt[\([2]\)]]\)], "Input",
  CellLabel->"In[15]:="],

Cell[BoxData[
    \(\[ExponentialE]\^\(-x\)\)], "Output",
  CellLabel->"Out[15]="]
}, Open  ]],

Cell["The verification shows that the proper asymptotic was found:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MrvLimit[f/lt, x \[Rule] \[Infinity]]\)], "Input",
  CellLabel->"In[16]:="],

Cell[BoxData[
    \(1\)], "Output",
  CellLabel->"Out[16]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Cache control", "Subsubsection"],

Cell[TextData[{
  "By setting the option ",
  StyleBox["ClearCache\[Rule]True",
    FontFamily->"Courier New"],
  StyleBox[", the algorithm-internal result cache will be cleared, before the \
calculation of the limit is done. Each calculated limit is stored in the \
cache, and repeated calculation of the same limit will be avoided. Clearing \
the cache is required if environmental conditions change that have influence \
on the limiting behaviour:",
    FontFamily->"Times New Roman"]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Unprotect[Sign]; Sign[a] = 1; Protect[Sign];\), "\[IndentingNewLine]", 
    \(MrvLimit[\[ExponentialE]\^\(a\ x\), x \[Rule] \[Infinity]]\)}], "Input",\

  CellLabel->"In[17]:="],

Cell[BoxData[
    \(\[Infinity]\)], "Output",
  CellLabel->"Out[18]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Unprotect[Sign]; Sign[a] = \(-1\); 
    Protect[Sign];\), "\[IndentingNewLine]", 
    \(MrvLimit[\[ExponentialE]\^\(a\ x\), x \[Rule] \[Infinity]]\)}], "Input",\

  CellLabel->"In[19]:="],

Cell[BoxData[
    \(\[Infinity]\)], "Output",
  CellLabel->"Out[20]="]
}, Open  ]],

Cell["\<\
This result is wrong, since the sign of a has an influence on the limit \
result, and the cached result is no longer valid.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MrvLimit[\[ExponentialE]\^\(a\ x\), x \[Rule] \[Infinity], 
      ClearCache \[Rule] True]\)], "Input",
  CellLabel->"In[21]:="],

Cell[BoxData[
    \(0\)], "Output",
  CellLabel->"Out[21]="]
}, Open  ]],

Cell[BoxData[
    \(Unprotect[Sign]; Sign[a] =. ; Protect[Sign];\)], "Input",
  CellLabel->"In[22]:="],

Cell[TextData[{
  StyleBox["Alternatively, the cache can be cleared by calling ",
    FontFamily->"Times New Roman"],
  StyleBox["MrvLimitClearCache",
    FontFamily->"Courier New"],
  StyleBox["[] directly.",
    FontFamily->"Times New Roman"],
  StyleBox["\nMrvLimitGetCacheStats",
    FontFamily->"Courier New"],
  "[] returns statistic data about the usage of the cache:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MrvLimitGetCacheStats[]\)], "Input",
  CellLabel->"In[23]:="],

Cell[BoxData[
    \({CacheHits \[Rule] 52, CacheMisses \[Rule] 13}\)], "Output",
  CellLabel->"Out[23]="]
}, Open  ]],

Cell[TextData[{
  StyleBox["CacheHits",
    FontFamily->"Courier New"],
  " describes, how many limit calculations could be avoided by using cached \
results, ",
  StyleBox["CacheMisses",
    FontFamily->"Courier New"],
  " describes, how many limit calculations actually took place."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Debug information", "Subsubsection"],

Cell[TextData[{
  "With ",
  StyleBox["Debug",
    FontFamily->"Courier New"],
  "\[Rule]",
  StyleBox["n",
    FontSlant->"Italic"],
  ", the debug output of the MrvLimit algorithm is activated. ",
  StyleBox["n",
    FontSlant->"Italic"],
  " describes, to which recursive nesting level the debug information is \
displayed. ",
  StyleBox["Debug",
    FontFamily->"Courier New"],
  "\[Rule]\[Infinity] gives debug information for any nesting level."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MrvLimit[E^x, x \[Rule] \[Infinity], Debug \[Rule] 1, 
      ClearCache \[Rule] True]\)], "Input",
  CellLabel->"In[24]:="],

Cell[BoxData[
    TagBox[
      AdjustmentBox[
        InterpretationBox[
          
          RowBox[{"\<\"Enter Level \"\>", "\[InvisibleSpace]", "1", 
            "\[InvisibleSpace]", "\<\" Call \"\>", "\[InvisibleSpace]", 
            
            TagBox[\(MrvLimitInf[\[ExponentialE]\^x, x, 
                Debug \[Rule] \[Infinity]]\),
              HoldForm]}],
          SequenceForm[ "Enter Level ", 1, " Call ", 
            HoldForm[ 
              MrvLimitInf[ 
                power[ E, x], x, Debug -> DirectedInfinity[ 1]]]],
          Editable->False],
        BoxMargins->{{0, 0}, {0, 0}}],
      DisplayForm]], "Print",
  CellLabel->"From In[24]:="],

Cell[BoxData[
    TagBox[
      AdjustmentBox[
        InterpretationBox[\("Calculating limit of "\[InvisibleSpace]\
\[ExponentialE]\^x\),
          SequenceForm[ "Calculating limit of ", 
            power[ E, x]],
          Editable->False],
        BoxMargins->{{0, 0}, {0, 0}}],
      DisplayForm]], "Print",
  CellLabel->"From In[24]:="],

Cell[BoxData[
    TagBox[
      AdjustmentBox[
        InterpretationBox[\("Calculating Mrv set of "\[InvisibleSpace]\
\[ExponentialE]\^x\),
          SequenceForm[ "Calculating Mrv set of ", 
            power[ E, x]],
          Editable->False],
        BoxMargins->{{0, 0}, {0, 0}}],
      DisplayForm]], "Print",
  CellLabel->"From In[24]:="],

Cell[BoxData[
    TagBox[
      AdjustmentBox[
        InterpretationBox[\("\[CapitalOmega]="\[InvisibleSpace]{MrvF[\
\[ExponentialE]\^x, 3, \[Infinity]]}\),
          SequenceForm[ "\[CapitalOmega]=", {
            MrvF[ 
              power[ E, x], 3, 
              DirectedInfinity[ 1]]}],
          Editable->False],
        BoxMargins->{{0, 0}, {0, 0}}],
      DisplayForm]], "Print",
  CellLabel->"From In[24]:="],

Cell[BoxData[
    TagBox[
      AdjustmentBox[
        InterpretationBox[\("\[Omega]="\[InvisibleSpace]\[ExponentialE]\^x\),
          SequenceForm[ "\[Omega]=", 
            power[ E, x]],
          Editable->False],
        BoxMargins->{{0, 0}, {0, 0}}],
      DisplayForm]], "Print",
  CellLabel->"From In[24]:="],

Cell[BoxData[
    TagBox[
      AdjustmentBox[
        InterpretationBox[\("Replacing \[Omega]\[Rule]1/\[Omega]: \[Omega]="\
\[InvisibleSpace]\[ExponentialE]\^\(-x\)\),
          SequenceForm[ "Replacing \[Omega]\[Rule]1/\[Omega]: \[Omega]=", 
            power[ E, 
              Times[ -1, x]]],
          Editable->False],
        BoxMargins->{{0, 0}, {0, 0}}],
      DisplayForm]], "Print",
  CellLabel->"From In[24]:="],

Cell[BoxData[
    TagBox[
      AdjustmentBox[
        InterpretationBox[\("Prepare to rewrite g="\[InvisibleSpace]\
\[ExponentialE]\^x\[InvisibleSpace]" to A*\[Omega]^c"\),
          SequenceForm[ "Prepare to rewrite g=", 
            power[ E, x], " to A*\[Omega]^c"],
          Editable->False],
        BoxMargins->{{0, 0}, {0, 0}}],
      DisplayForm]], "Print",
  CellLabel->"From In[24]:="],

Cell[BoxData[
    TagBox[
      AdjustmentBox[
        InterpretationBox[\("c="\[InvisibleSpace]\(-1\)\[InvisibleSpace]" A="\
\[InvisibleSpace]1\),
          SequenceForm[ "c=", -1, " A=", 1],
          Editable->False],
        BoxMargins->{{0, 0}, {0, 0}}],
      DisplayForm]], "Print",
  CellLabel->"From In[24]:="],

Cell[BoxData[
    TagBox[
      AdjustmentBox[
        InterpretationBox[\("Rewriting "\[InvisibleSpace]\[ExponentialE]\^x\
\[InvisibleSpace]"\[Rule]"\[InvisibleSpace]1\/\[Omega]\[InvisibleSpace]"\n"\
\[InvisibleSpace]"f="\[InvisibleSpace]1\/\[Omega]\),
          SequenceForm[ "Rewriting ", 
            power[ E, x], "\[Rule]", 
            power[ \[Omega], -1], "\n", "f=", 
            power[ \[Omega], -1]],
          Editable->False],
        BoxMargins->{{0, 0}, {0, 0}}],
      DisplayForm]], "Print",
  CellLabel->"From In[24]:="],

Cell[BoxData[
    TagBox[
      AdjustmentBox[
        InterpretationBox[\("Calculating power series: \
f="\[InvisibleSpace]1\/\[Omega]\),
          SequenceForm[ "Calculating power series: f=", 
            power[ \[Omega], -1]],
          Editable->False],
        BoxMargins->{{0, 0}, {0, 0}}],
      DisplayForm]], "Print",
  CellLabel->"From In[24]:="],

Cell[BoxData[
    TagBox[
      AdjustmentBox[
        InterpretationBox[
          RowBox[{"\<\"Series expansion: \"\>", "\[InvisibleSpace]", 
            InterpretationBox[
              RowBox[{\(1\/\[Omega]\), "+", 
                InterpretationBox[\(O[\[Omega]]\^2\),
                  SeriesData[ \[Omega], 0, {}, -1, 2, 1],
                  Editable->False]}],
              SeriesData[ \[Omega], 0, {1}, -1, 2, 1],
              Editable->False]}],
          SequenceForm[ "Series expansion: ", 
            SeriesData[ \[Omega], 0, {1}, -1, 2, 1]],
          Editable->False],
        BoxMargins->{{0, 0}, {0, 0}}],
      DisplayForm]], "Print",
  CellLabel->"From In[24]:="],

Cell[BoxData[
    TagBox[
      AdjustmentBox[
        InterpretationBox[\("Dominant term: "\[InvisibleSpace]1\/\[Omega]\
\[InvisibleSpace]" , \[Omega]="\[InvisibleSpace]\[ExponentialE]\^\(-x\)\),
          SequenceForm[ "Dominant term: ", 
            power[ \[Omega], -1], " , \[Omega]=", 
            power[ E, 
              Times[ -1, x]]],
          Editable->False],
        BoxMargins->{{0, 0}, {0, 0}}],
      DisplayForm]], "Print",
  CellLabel->"From In[24]:="],

Cell[BoxData[
    TagBox[
      AdjustmentBox[
        InterpretationBox[\("Dominant asymptotic: "\[InvisibleSpace]1\
\[InvisibleSpace]1\/\[ExponentialE]\^\(-x\)\),
          SequenceForm[ "Dominant asymptotic: ", 1, 
            power[ 
              power[ E, 
                Times[ -1, x]], -1]],
          Editable->False],
        BoxMargins->{{0, 0}, {0, 0}}],
      DisplayForm]], "Print",
  CellLabel->"From In[24]:="],

Cell[BoxData[
    TagBox[
      AdjustmentBox[
        InterpretationBox[
          
          RowBox[{"\<\"Leave Level \"\>", "\[InvisibleSpace]", "1", 
            "\[InvisibleSpace]", "\<\" Call \"\>", "\[InvisibleSpace]", 
            
            TagBox[\(MrvLimitInf[\[ExponentialE]\^x, x, 
                  Debug \[Rule] \[Infinity]] \[Equal] \[Infinity]\),
              HoldForm]}],
          SequenceForm[ "Leave Level ", 1, " Call ", 
            HoldForm[ 
              Equal[ 
                MrvLimitInf[ 
                  power[ E, x], x, Debug -> DirectedInfinity[ 1]], 
                DirectedInfinity[ 1]]]],
          Editable->False],
        BoxMargins->{{0, 0}, {0, 0}}],
      DisplayForm]], "Print",
  CellLabel->"From In[24]:="],

Cell[BoxData[
    \(\[Infinity]\)], "Output",
  CellLabel->"Out[24]="]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Helper functions", "Section"],

Cell[CellGroupData[{

Cell["ToInternal / FromInternal", "Subsubsection"],

Cell[TextData[{
  "MrvLimit uses internally a different function format, in which certain \
functions are replaced by alternate notations. By using these alternate \
notations, problematic effects of automatic transformations can be avoided. \
MrvLimit automatically translates input and output to internal format and \
back automatically. Only in certain advanced situations, the internal format \
is used.\n\nFunctions and their internal format in ",
  StyleBox["MrvLimit",
    FontFamily->"Courier New"],
  ":\n\n",
  Cell[BoxData[GridBox[{
          {
            StyleBox["Function",
              FontWeight->"Bold"], 
            StyleBox[\(Internal\ Format\),
              FontWeight->"Bold"]},
          {"Power", "power"},
          {"Log", "log"},
          {"Sin", "sin"},
          {"Cos", "cos"},
          {"Tan", "tan"},
          {"ArcSin", "arcsin"},
          {"ArcCos", "arccos"},
          {"ArcTan", "arctan"},
          {"Gamma", "gamma"},
          {"LogGamma", "loggamma"},
          {"PolyGamma", "polygamma"}
          },
        ColumnAlignments->{Left}]]],
  "\n\nThe display of internal functions is identical to the original ",
  "Mathematica format:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(power[E, x] + Power[E, x]\)], "Input",
  CellLabel->"In[25]:="],

Cell[BoxData[
    \(\[ExponentialE]\^x + \[ExponentialE]\^x\)], "Output",
  CellLabel->"Out[25]="]
}, Open  ]],

Cell[TextData[{
  "To convert between internal and ",
  "Mathematica",
  " format, the two helper functions ",
  StyleBox["ToInternal[",
    FontFamily->"Courier New"],
  StyleBox["f",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[",",
    FontFamily->"Courier New"],
  StyleBox["x",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier New"],
  " and ",
  StyleBox["FromInternal[",
    FontFamily->"Courier New"],
  StyleBox["f",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[",",
    FontFamily->"Courier New"],
  StyleBox["x",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier New"],
  " can be used:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(f = ToInternal[E^x*Sin[x]^c, x]\)], "Input",
  CellLabel->"In[26]:="],

Cell[BoxData[
    \(\[ExponentialE]\^x\ Sin[x]\^c\)], "Output",
  CellLabel->"Out[26]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(f = f /. c \[Rule] 0\)], "Input",
  CellLabel->"In[27]:="],

Cell[BoxData[
    \(\[ExponentialE]\^x\ Sin[x]\^0\)], "Output",
  CellLabel->"Out[27]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(FromInternal[f, x]\)], "Input",
  CellLabel->"In[28]:="],

Cell[BoxData[
    \(\[ExponentialE]\^x\)], "Output",
  CellLabel->"Out[28]="]
}, Open  ]],

Cell[TextData[{
  StyleBox["ToInternal",
    FontFamily->"Courier New"],
  " only processes functions that are known to the algorithm:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ToInternal[Foo[x], x]\)], "Input",
  CellLabel->"In[29]:="],

Cell[BoxData[
    \(MrvLimit::"UnsupportedFunction" \(\(:\)\(\ \)\) 
      "MrvLimit does not support this function: \!\(Foo[x]\)"\)], "Message",
  CellLabel->"From In[29]:="],

Cell[BoxData[
    TagBox[\(ToInternal[Foo[x], x]\),
      HoldForm]], "Output",
  CellLabel->"Out[29]="]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Extension interfaces", "Section"],

Cell[CellGroupData[{

Cell["Power series", "Subsubsection"],

Cell[TextData[{
  StyleBox["MrvLimit",
    FontFamily->"Courier New"],
  " depends on a good algorithm for determining power series, but depends \
itself only on the limited possibilites of the ",
  StyleBox["Series",
    FontFamily->"Courier New"],
  " command of ",
  "Mathematica.",
  " Often even a small modification of the appearing function may be enough \
to determine the power series of the function correctly. Or maybe a \
completely different power series algorithm is available. By setting the \
variable ",
  StyleBox["$MrvSeriesHead",
    FontFamily->"Courier New"],
  ", such a handler can be integrated into MrvLimit:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MrvLimit[\((\[ExponentialE]\^x\ x)\)\^\(1\/x\), 
      x \[Rule] \[Infinity]]\)], "Input",
  CellLabel->"In[30]:="],

Cell[BoxData[
    \(MrvLimit::"SeriesFail" \(\(:\)\(\ \)\) 
      "Series failed at \
\!\(\[ExponentialE]\^\(\(Log[\(\(x\/\[Omega]\)\)]\)\/x\)\)"\)], "Message",
  CellLabel->"From In[30]:="],

Cell[BoxData[
    TagBox[\(MrvLimit[\((\[ExponentialE]\^x\ x)\)\^\(1\/x\), 
        x \[Rule] \[Infinity]]\),
      HoldForm]], "Output",
  CellLabel->"Out[30]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(SeriesHelper[f_, x_, \[Omega]_, log\[Omega]_, dprint_] := 
        Module[{}, \[IndentingNewLine]If[
            FromInternal[f, 
                x] === \((x\/\[Omega])\)\^\(1\/x\), \
\[IndentingNewLine]\(Return[{ToInternal[\[ExponentialE]\^\(1 + Log[x]\/x\), 
                    x], 0}];\)\[IndentingNewLine]]; \
\[IndentingNewLine]MrvSeriesHead[f, x, \[Omega], log\[Omega], 
            dprint]\[IndentingNewLine]];\)\), "\[IndentingNewLine]", 
    \(\($MrvSeriesHead = SeriesHelper;\)\), "\[IndentingNewLine]", 
    \(\(res = 
        MrvLimit[\((\[ExponentialE]\^x\ x)\)\^\(1\/x\), 
          x \[Rule] \[Infinity], 
          ClearCache \[Rule] True];\)\), "\[IndentingNewLine]", 
    \(\($MrvSeriesHead = MrvSeriesHead;\)\), "\[IndentingNewLine]", 
    \(res\)}], "Input",
  CellLabel->"In[31]:="],

Cell[BoxData[
    \(\[ExponentialE]\)], "Output",
  CellLabel->"Out[35]="]
}, Open  ]],

Cell[TextData[{
  "For detailed information about the interface, check the source code of the \
",
  StyleBox["MrvSeriesHead",
    FontFamily->"Courier New"],
  " function."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Zero tests", "Subsubsection"],

Cell[TextData[{
  "Just like the Series command of ",
  "Mathematica",
  ", the zero tests are a critical weakness of the algorithm. They can be \
replaced easily too. ",
  StyleBox["$MrvTestZero",
    FontFamily->"Courier New"],
  " points to a function for testing terms to be 0. The default value is ",
  StyleBox["$MrvTestZero=MrvTestZero",
    FontFamily->"Courier New"],
  " using:\n\n",
  StyleBox["MrvTestZero[term_,x_]:=Simplify[FromInternal[term,x]==0];\n",
    FontFamily->"Courier New"],
  StyleBox["\nAlternatively, the faster, but less precise variant ",
    FontFamily->"Times New Roman"],
  StyleBox["FromInternal[term,x]==0",
    FontFamily->"Courier New"],
  StyleBox[" can be used, or the more precise but noticeably slower variant ",
    
    FontFamily->"Times New Roman"],
  StyleBox["Simplify[FromInternal[term,x]==0,Element[x,Reals]]",
    FontFamily->"Courier New"],
  StyleBox[". \nMathematica also provides the variant ",
    FontFamily->"Times New Roman"],
  StyleBox["Developer`ZeroQ[FromInternal[term,x]]",
    FontFamily->"Courier New"],
  StyleBox[".\n\nTo check functions about being the zero function in an \
environment of the limit point (normally \[Infinity]), the variable ",
    FontFamily->"Times New Roman"],
  StyleBox["$MrvTestZeroInterval",
    FontFamily->"Courier New"],
  " is used. The default value is ",
  StyleBox["$MrvTestZeroInterval = MrvTestZeroInterval",
    FontFamily->"Courier New"],
  ", using:",
  StyleBox["\n\n",
    FontFamily->"Times New Roman"],
  StyleBox["MrvTestZeroInterval[term_,x_\[Rule]\[Infinity]]:=Simplify[\
FromInternal[term,x]==0];",
    FontFamily->"Courier New"],
  StyleBox["\n\nBeside the variants shown above, this test can also use the \
actual environment, for example by using ",
    FontFamily->"Times New Roman"],
  StyleBox["Simplify[FromInternal[term,x]==0,x>10^1000]",
    FontFamily->"Courier New"],
  StyleBox[". Unfortunately, this variant is also rather slow, and because of \
that the default is a simle zero test without referencing x.",
    FontFamily->"Times New Roman"]
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Debug output", "Subsubsection"],

Cell[TextData[{
  "If there is need for a different output format for the ",
  StyleBox["Debug",
    FontFamily->"Courier New"],
  " option, the output function can be announced using the ",
  StyleBox["$DebugPrint",
    FontFamily->"Courier New"],
  " variable:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(MyPrint[Indent_, Text__] := 
        Print["\<Debug[\>", Indent, "\<]:\>", 
          Text];\)\), "\[IndentingNewLine]", 
    \(\($DebugPrint = MyPrint;\)\), "\[IndentingNewLine]", 
    \(\(MrvLimit[E^x, x \[Rule] \[Infinity], 
        Debug \[Rule] 1];\)\), "\[IndentingNewLine]", 
    \(\($DebugPrint = IndentPrint;\)\)}], "Input",
  CellLabel->"In[36]:="],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"Debug[\"\>", "\[InvisibleSpace]", "0", 
        "\[InvisibleSpace]", "\<\"]:\"\>", 
        "\[InvisibleSpace]", "\<\"Enter Level \"\>", "\[InvisibleSpace]", "1",
         "\[InvisibleSpace]", "\<\" Call \"\>", "\[InvisibleSpace]", 
        TagBox[\(MrvLimitInf[\[ExponentialE]\^x, x, Debug \[Rule] 1]\),
          HoldForm]}],
      SequenceForm[ "Debug[", 0, "]:", "Enter Level ", 1, " Call ", 
        HoldForm[ 
          MrvLimitInf[ 
            power[ E, x], x, Debug -> 1]]],
      Editable->False]], "Print",
  CellLabel->"From In[54]:="],

Cell[BoxData[
    InterpretationBox[\("Debug["\[InvisibleSpace]0\[InvisibleSpace]"]:"\
\[InvisibleSpace]"Taking cached result"\),
      SequenceForm[ "Debug[", 0, "]:", "Taking cached result"],
      Editable->False]], "Print",
  CellLabel->"From In[54]:="],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"Debug[\"\>", "\[InvisibleSpace]", "0", 
        "\[InvisibleSpace]", "\<\"]:\"\>", 
        "\[InvisibleSpace]", "\<\"Leave Level \"\>", "\[InvisibleSpace]", "1",
         "\[InvisibleSpace]", "\<\" Call \"\>", "\[InvisibleSpace]", 
        TagBox[\(MrvLimitInf[\[ExponentialE]\^x, x, 
              Debug \[Rule] 1] \[Equal] \[Infinity]\),
          HoldForm]}],
      SequenceForm[ "Debug[", 0, "]:", "Leave Level ", 1, " Call ", 
        HoldForm[ 
          Equal[ 
            MrvLimitInf[ 
              power[ E, x], x, Debug -> 1], 
            DirectedInfinity[ 1]]]],
      Editable->False]], "Print",
  CellLabel->"From In[54]:="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Output control", "Subsubsection"],

Cell[TextData[{
  "Displayed function terms may be quite large, and it may be useful to \
filter such output. By setting the ",
  StyleBox["$OutputProcessor",
    FontFamily->"Courier New"],
  StyleBox[" variable, each debug output and each message output can be post \
processed:",
    FontFamily->"Times New Roman"]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(f = \[ExponentialE]\^\(\[ExponentialE]\^\(h - x\) + h - x\/\(1 + \
h\)\)\  /. h -> \ 
            1\/\(1 + \[ExponentialE]\^\(-x\)\);\)\), "\[IndentingNewLine]", 
    \(\($OutputProcessor = \((FromInternal[#, 
                x] /. {1\/\(1 + \[ExponentialE]\^\(-x\)\) \[Rule] 
                  h} &)\);\)\), "\[IndentingNewLine]", 
    \(\(MrvLimit[f, x \[Rule] \[Infinity], Debug \[Rule] 1, 
        ClearCache \[Rule] True];\)\), "\[IndentingNewLine]", 
    \(\($OutputProcessor = Identity;\)\)}], "Input",
  CellLabel->"In[40]:="],

Cell[BoxData[
    TagBox[
      AdjustmentBox[
        InterpretationBox[
          
          RowBox[{"\<\"Enter Level \"\>", "\[InvisibleSpace]", "1", 
            "\[InvisibleSpace]", "\<\" Call \"\>", "\[InvisibleSpace]", 
            
            TagBox[\(MrvLimitInf[\[ExponentialE]\^\(\[ExponentialE]\^\(\(-x\) \
+ h\) + h - x\/\(1 + h\)\), x, Debug \[Rule] 1]\),
              HoldForm]}],
          SequenceForm[ "Enter Level ", 1, " Call ", 
            HoldForm[ 
              MrvLimitInf[ 
                Power[ E, 
                  Plus[ 
                    Power[ E, 
                      Plus[ 
                        Times[ -1, x], h]], h, 
                    Times[ -1, x, 
                      Power[ 
                        Plus[ 1, h], -1]]]], x, Debug -> 1]]],
          Editable->False],
        BoxMargins->{{0, 0}, {0, 0}}],
      DisplayForm]], "Print",
  CellLabel->"From In[40]:="],

Cell[BoxData[
    TagBox[
      AdjustmentBox[
        InterpretationBox[\("Calculating limit of "\[InvisibleSpace]\
\[ExponentialE]\^\(\[ExponentialE]\^\(h - x\) + h - x\/\(1 + h\)\)\),
          SequenceForm[ "Calculating limit of ", 
            Power[ E, 
              Plus[ 
                Power[ E, 
                  Plus[ h, 
                    Times[ -1, x]]], h, 
                Times[ -1, 
                  Power[ 
                    Plus[ 1, h], -1], x]]]],
          Editable->False],
        BoxMargins->{{0, 0}, {0, 0}}],
      DisplayForm]], "Print",
  CellLabel->"From In[40]:="],

Cell[BoxData[
    TagBox[
      AdjustmentBox[
        InterpretationBox[\("Calculating Mrv set of "\[InvisibleSpace]\
\[ExponentialE]\^\(\[ExponentialE]\^\(h - x\) + h - x\/\(1 + h\)\)\),
          SequenceForm[ "Calculating Mrv set of ", 
            Power[ E, 
              Plus[ 
                Power[ E, 
                  Plus[ h, 
                    Times[ -1, x]]], h, 
                Times[ -1, 
                  Power[ 
                    Plus[ 1, h], -1], x]]]],
          Editable->False],
        BoxMargins->{{0, 0}, {0, 0}}],
      DisplayForm]], "Print",
  CellLabel->"From In[40]:="],

Cell[BoxData[
    TagBox[
      AdjustmentBox[
        InterpretationBox[\("\[CapitalOmega]="\[InvisibleSpace]{MrvF[\
\[ExponentialE]\^\(-x\), 5, 0], MrvF[\[ExponentialE]\^\(h - x\), 15, 0], 
              MrvF[\[ExponentialE]\^\(\[ExponentialE]\^\(h - x\) + h - x\/\(1 \
+ h\)\), 43, 0]}\),
          SequenceForm[ "\[CapitalOmega]=", {
            MrvF[ 
              Power[ E, 
                Times[ -1, x]], 5, 0], 
            MrvF[ 
              Power[ E, 
                Plus[ h, 
                  Times[ -1, x]]], 15, 0], 
            MrvF[ 
              Power[ E, 
                Plus[ 
                  Power[ E, 
                    Plus[ h, 
                      Times[ -1, x]]], h, 
                  Times[ -1, 
                    Power[ 
                      Plus[ 1, h], -1], x]]], 43, 0]}],
          Editable->False],
        BoxMargins->{{0, 0}, {0, 0}}],
      DisplayForm]], "Print",
  CellLabel->"From In[40]:="],

Cell[BoxData[
    TagBox[
      AdjustmentBox[
        InterpretationBox[\("\[Omega]="\[InvisibleSpace]\[ExponentialE]\^\(-x\
\)\),
          SequenceForm[ "\[Omega]=", 
            Power[ E, 
              Times[ -1, x]]],
          Editable->False],
        BoxMargins->{{0, 0}, {0, 0}}],
      DisplayForm]], "Print",
  CellLabel->"From In[40]:="],

Cell[BoxData[
    TagBox[
      AdjustmentBox[
        InterpretationBox[\("Prepare to rewrite g="\[InvisibleSpace]\
\[ExponentialE]\^\(\[ExponentialE]\^\(h - x\) + h - x\/\(1 + h\)\)\
\[InvisibleSpace]" to A*\[Omega]^c"\),
          SequenceForm[ "Prepare to rewrite g=", 
            Power[ E, 
              Plus[ 
                Power[ E, 
                  Plus[ h, 
                    Times[ -1, x]]], h, 
                Times[ -1, 
                  Power[ 
                    Plus[ 1, h], -1], x]]], " to A*\[Omega]^c"],
          Editable->False],
        BoxMargins->{{0, 0}, {0, 0}}],
      DisplayForm]], "Print",
  CellLabel->"From In[40]:="],

Cell[BoxData[
    TagBox[
      AdjustmentBox[
        InterpretationBox[\("c="\[InvisibleSpace]1\/2\[InvisibleSpace]" A="\
\[InvisibleSpace]\[ExponentialE]\^\(\[ExponentialE]\^\(h - x\) + h + x\/2 - x\
\/\(1 + h\)\)\),
          SequenceForm[ "c=", 
            Rational[ 1, 2], " A=", 
            Power[ E, 
              Plus[ 
                Power[ E, 
                  Plus[ h, 
                    Times[ -1, x]]], h, 
                Times[ 
                  Rational[ 1, 2], x], 
                Times[ -1, 
                  Power[ 
                    Plus[ 1, h], -1], x]]]],
          Editable->False],
        BoxMargins->{{0, 0}, {0, 0}}],
      DisplayForm]], "Print",
  CellLabel->"From In[40]:="],

Cell[BoxData[
    TagBox[
      AdjustmentBox[
        InterpretationBox[\("Rewriting "\[InvisibleSpace]\[ExponentialE]\^\(\
\[ExponentialE]\^\(h - x\) + h - x\/\(1 + h\)\)\[InvisibleSpace]"\[Rule]"\
\[InvisibleSpace]\(\[ExponentialE]\^\(\[ExponentialE]\^\(h - x\) + h + x\/2 - \
x\/\(1 + h\)\)\ \@\[Omega]\)\[InvisibleSpace]"\n"\[InvisibleSpace]"f="\
\[InvisibleSpace]\(\[ExponentialE]\^\(\[ExponentialE]\^\(h - x\) + h + x\/2 - \
x\/\(1 + h\)\)\ \@\[Omega]\)\),
          SequenceForm[ "Rewriting ", 
            Power[ E, 
              Plus[ 
                Power[ E, 
                  Plus[ h, 
                    Times[ -1, x]]], h, 
                Times[ -1, 
                  Power[ 
                    Plus[ 1, h], -1], x]]], "\[Rule]", 
            Times[ 
              Power[ E, 
                Plus[ 
                  Power[ E, 
                    Plus[ h, 
                      Times[ -1, x]]], h, 
                  Times[ 
                    Rational[ 1, 2], x], 
                  Times[ -1, 
                    Power[ 
                      Plus[ 1, h], -1], x]]], 
              Power[ \[Omega], 
                Rational[ 1, 2]]], "\n", "f=", 
            Times[ 
              Power[ E, 
                Plus[ 
                  Power[ E, 
                    Plus[ h, 
                      Times[ -1, x]]], h, 
                  Times[ 
                    Rational[ 1, 2], x], 
                  Times[ -1, 
                    Power[ 
                      Plus[ 1, h], -1], x]]], 
              Power[ \[Omega], 
                Rational[ 1, 2]]]],
          Editable->False],
        BoxMargins->{{0, 0}, {0, 0}}],
      DisplayForm]], "Print",
  CellLabel->"From In[40]:="],

Cell[BoxData[
    TagBox[
      AdjustmentBox[
        InterpretationBox[\("Prepare to rewrite g="\[InvisibleSpace]\
\[ExponentialE]\^\(h - x\)\[InvisibleSpace]" to A*\[Omega]^c"\),
          SequenceForm[ "Prepare to rewrite g=", 
            Power[ E, 
              Plus[ h, 
                Times[ -1, x]]], " to A*\[Omega]^c"],
          Editable->False],
        BoxMargins->{{0, 0}, {0, 0}}],
      DisplayForm]], "Print",
  CellLabel->"From In[40]:="],

Cell[BoxData[
    TagBox[
      AdjustmentBox[
        InterpretationBox[\("c="\[InvisibleSpace]1\[InvisibleSpace]" A="\
\[InvisibleSpace]\[ExponentialE]\^h\),
          SequenceForm[ "c=", 1, " A=", 
            Power[ E, h]],
          Editable->False],
        BoxMargins->{{0, 0}, {0, 0}}],
      DisplayForm]], "Print",
  CellLabel->"From In[40]:="],

Cell[BoxData[
    TagBox[
      AdjustmentBox[
        InterpretationBox[\("Rewriting "\[InvisibleSpace]\[ExponentialE]\^\(h \
- x\)\[InvisibleSpace]"\[Rule]"\[InvisibleSpace]\(\[ExponentialE]\^h\ \
\[Omega]\)\[InvisibleSpace]"\n"\[InvisibleSpace]"f="\[InvisibleSpace]\(\
\[ExponentialE]\^\(h + x\/2 - x\/\(1 + h\) + \[ExponentialE]\^h\ \[Omega]\)\ \
\@\[Omega]\)\),
          SequenceForm[ "Rewriting ", 
            Power[ E, 
              Plus[ h, 
                Times[ -1, x]]], "\[Rule]", 
            Times[ 
              Power[ E, h], \[Omega]], "\n", "f=", 
            Times[ 
              Power[ E, 
                Plus[ h, 
                  Times[ 
                    Rational[ 1, 2], x], 
                  Times[ -1, 
                    Power[ 
                      Plus[ 1, h], -1], x], 
                  Times[ 
                    Power[ E, h], \[Omega]]]], 
              Power[ \[Omega], 
                Rational[ 1, 2]]]],
          Editable->False],
        BoxMargins->{{0, 0}, {0, 0}}],
      DisplayForm]], "Print",
  CellLabel->"From In[40]:="],

Cell[BoxData[
    TagBox[
      AdjustmentBox[
        InterpretationBox[\("Prepare to rewrite g="\[InvisibleSpace]\
\[ExponentialE]\^\(-x\)\[InvisibleSpace]" to A*\[Omega]^c"\),
          SequenceForm[ "Prepare to rewrite g=", 
            Power[ E, 
              Times[ -1, x]], " to A*\[Omega]^c"],
          Editable->False],
        BoxMargins->{{0, 0}, {0, 0}}],
      DisplayForm]], "Print",
  CellLabel->"From In[40]:="],

Cell[BoxData[
    TagBox[
      AdjustmentBox[
        InterpretationBox[\("c="\[InvisibleSpace]1\[InvisibleSpace]" A="\
\[InvisibleSpace]1\),
          SequenceForm[ "c=", 1, " A=", 1],
          Editable->False],
        BoxMargins->{{0, 0}, {0, 0}}],
      DisplayForm]], "Print",
  CellLabel->"From In[40]:="],

Cell[BoxData[
    TagBox[
      AdjustmentBox[
        InterpretationBox[\("Rewriting \
"\[InvisibleSpace]\[ExponentialE]\^\(-x\)\[InvisibleSpace]"\[Rule]"\
\[InvisibleSpace]\[Omega]\[InvisibleSpace]"\n"\[InvisibleSpace]"f="\
\[InvisibleSpace]\(\[ExponentialE]\^\(x\/2 + \[ExponentialE]\^\(1\/\(1 + \
\[Omega]\)\)\ \[Omega] + 1\/\(1 + \[Omega]\) - x\/\(1 + 1\/\(1 + \[Omega]\)\)\
\)\ \@\[Omega]\)\),
          SequenceForm[ "Rewriting ", 
            Power[ E, 
              Times[ -1, x]], "\[Rule]", \[Omega], "\n", "f=", 
            Times[ 
              Power[ E, 
                Plus[ 
                  Times[ 
                    Rational[ 1, 2], x], 
                  Times[ 
                    Power[ E, 
                      Power[ 
                        Plus[ 1, \[Omega]], -1]], \[Omega]], 
                  Power[ 
                    Plus[ 1, \[Omega]], -1], 
                  Times[ -1, x, 
                    Power[ 
                      Plus[ 1, 
                        Power[ 
                          Plus[ 1, \[Omega]], -1]], -1]]]], 
              Power[ \[Omega], 
                Rational[ 1, 2]]]],
          Editable->False],
        BoxMargins->{{0, 0}, {0, 0}}],
      DisplayForm]], "Print",
  CellLabel->"From In[40]:="],

Cell[BoxData[
    TagBox[
      AdjustmentBox[
        InterpretationBox[\("Calculating power series: f="\[InvisibleSpace]\(\
\[ExponentialE]\^\(x\/2 + \[ExponentialE]\^\(1\/\(1 + \[Omega]\)\)\ \[Omega] \
+ 1\/\(1 + \[Omega]\) - x\/\(1 + 1\/\(1 + \[Omega]\)\)\)\ \@\[Omega]\)\),
          SequenceForm[ "Calculating power series: f=", 
            Times[ 
              Power[ E, 
                Plus[ 
                  Times[ 
                    Rational[ 1, 2], x], 
                  Times[ 
                    Power[ E, 
                      Power[ 
                        Plus[ 1, \[Omega]], -1]], \[Omega]], 
                  Power[ 
                    Plus[ 1, \[Omega]], -1], 
                  Times[ -1, x, 
                    Power[ 
                      Plus[ 1, 
                        Power[ 
                          Plus[ 1, \[Omega]], -1]], -1]]]], 
              Power[ \[Omega], 
                Rational[ 1, 2]]]],
          Editable->False],
        BoxMargins->{{0, 0}, {0, 0}}],
      DisplayForm]], "Print",
  CellLabel->"From In[40]:="],

Cell[BoxData[
    TagBox[
      AdjustmentBox[
        InterpretationBox[
          RowBox[{"\<\"Series expansion: \"\>", "\[InvisibleSpace]", 
            InterpretationBox[
              RowBox[{\(\[ExponentialE]\ \@\[Omega]\), "+", 
                InterpretationBox[\(O[\[Omega]]\^\(3/2\)\),
                  SeriesData[ \[Omega], 0, {}, 1, 3, 2],
                  Editable->False]}],
              SeriesData[ \[Omega], 0, {E}, 1, 3, 2],
              Editable->False]}],
          SequenceForm[ "Series expansion: ", 
            SeriesData[ \[Omega], 0, {E}, 1, 3, 2]],
          Editable->False],
        BoxMargins->{{0, 0}, {0, 0}}],
      DisplayForm]], "Print",
  CellLabel->"From In[40]:="],

Cell[BoxData[
    TagBox[
      AdjustmentBox[
        InterpretationBox[\("Dominant term: "\[InvisibleSpace]\(\
\[ExponentialE]\ \@\[Omega]\)\[InvisibleSpace]" , \[Omega]="\[InvisibleSpace]\
\[ExponentialE]\^\(-x\)\),
          SequenceForm[ "Dominant term: ", 
            Times[ E, 
              Power[ \[Omega], 
                Rational[ 1, 2]]], " , \[Omega]=", 
            Power[ E, 
              Times[ -1, x]]],
          Editable->False],
        BoxMargins->{{0, 0}, {0, 0}}],
      DisplayForm]], "Print",
  CellLabel->"From In[40]:="],

Cell[BoxData[
    TagBox[
      AdjustmentBox[
        InterpretationBox[\("Dominant asymptotic: "\[InvisibleSpace]\
\[ExponentialE]\[InvisibleSpace]\@\[ExponentialE]\^\(-x\)\),
          SequenceForm[ "Dominant asymptotic: ", E, 
            Power[ 
              Power[ E, 
                Times[ -1, x]], 
              Rational[ 1, 2]]],
          Editable->False],
        BoxMargins->{{0, 0}, {0, 0}}],
      DisplayForm]], "Print",
  CellLabel->"From In[40]:="],

Cell[BoxData[
    TagBox[
      AdjustmentBox[
        InterpretationBox[
          
          RowBox[{"\<\"Leave Level \"\>", "\[InvisibleSpace]", "1", 
            "\[InvisibleSpace]", "\<\" Call \"\>", "\[InvisibleSpace]", 
            
            TagBox[\(MrvLimitInf[\[ExponentialE]\^\(\[ExponentialE]\^\(\(-x\) \
+ h\) + h - x\/\(1 + h\)\), x, Debug \[Rule] 1] \[Equal] 0\),
              HoldForm]}],
          SequenceForm[ "Leave Level ", 1, " Call ", 
            HoldForm[ 
              Equal[ 
                MrvLimitInf[ 
                  Power[ E, 
                    Plus[ 
                      Power[ E, 
                        Plus[ 
                          Times[ -1, x], h]], h, 
                      Times[ -1, x, 
                        Power[ 
                          Plus[ 1, h], -1]]]], x, Debug -> 1], 0]]],
          Editable->False],
        BoxMargins->{{0, 0}, {0, 0}}],
      DisplayForm]], "Print",
  CellLabel->"From In[40]:="]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.0 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 887}},
WindowToolbars->{},
WindowSize->{831, 811},
WindowMargins->{{129, Automatic}, {Automatic, 6}},
Magnification->1.25,
StyleDefinitions -> "ArticleModern.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 37, 0, 108, "Title"],
Cell[1816, 55, 428, 7, 94, "Text"],

Cell[CellGroupData[{
Cell[2269, 66, 38, 0, 79, "Section"],
Cell[2310, 68, 457, 18, 52, "Text"],

Cell[CellGroupData[{
Cell[2792, 90, 79, 2, 53, "Input"],
Cell[2874, 94, 233, 4, 111, "Print"]
}, Open  ]],
Cell[3122, 101, 86, 2, 31, "Text"],

Cell[CellGroupData[{
Cell[3233, 107, 114, 2, 53, "Input"],
Cell[3350, 111, 233, 4, 111, "Print"]
}, Open  ]],
Cell[3598, 118, 108, 3, 31, "Text"],
Cell[3709, 123, 154, 3, 74, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3900, 131, 44, 0, 79, "Section"],
Cell[3947, 133, 172, 5, 31, "Text"],

Cell[CellGroupData[{
Cell[4144, 142, 169, 3, 96, "Input"],
Cell[4316, 147, 59, 2, 53, "Output"]
}, Open  ]],
Cell[4390, 152, 94, 2, 31, "Text"],

Cell[CellGroupData[{
Cell[4509, 158, 107, 2, 53, "Input"],
Cell[4619, 162, 69, 2, 53, "Output"]
}, Open  ]],
Cell[4703, 167, 284, 7, 52, "Text"],

Cell[CellGroupData[{
Cell[5012, 178, 81, 2, 53, "Input"],
Cell[5096, 182, 89, 2, 53, "Output"]
}, Open  ]],
Cell[5200, 187, 145, 3, 31, "Text"],

Cell[CellGroupData[{
Cell[5370, 194, 88, 2, 53, "Input"],
Cell[5461, 198, 69, 2, 53, "Output"]
}, Open  ]],
Cell[5545, 203, 201, 6, 31, "Text"],

Cell[CellGroupData[{
Cell[5771, 213, 88, 2, 53, "Input"],
Cell[5862, 217, 220, 4, 41, "Message"],
Cell[6085, 223, 114, 3, 67, "Output"]
}, Open  ]],
Cell[6214, 229, 193, 6, 31, "Text"],

Cell[CellGroupData[{
Cell[6432, 239, 324, 6, 96, "Input"],
Cell[6759, 247, 59, 2, 53, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6855, 254, 89, 2, 53, "Input"],
Cell[6947, 258, 282, 5, 72, "Output"]
}, Open  ]],
Cell[7244, 266, 381, 11, 73, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7662, 282, 35, 0, 79, "Section"],
Cell[7700, 284, 160, 4, 31, "Text"],

Cell[CellGroupData[{
Cell[7885, 292, 38, 0, 52, "Subsubsection"],
Cell[7926, 294, 6236, 202, 412, "Text"],

Cell[CellGroupData[{
Cell[14187, 500, 338, 8, 87, "Input"],
Cell[14528, 510, 254, 5, 59, "Output"]
}, Open  ]],
Cell[14797, 518, 465, 16, 75, "Text"],

Cell[CellGroupData[{
Cell[15287, 538, 82, 2, 53, "Input"],
Cell[15372, 542, 230, 5, 67, "Output"]
}, Open  ]],
Cell[15617, 550, 109, 3, 31, "Text"],

Cell[CellGroupData[{
Cell[15751, 557, 86, 2, 53, "Input"],
Cell[15840, 561, 106, 2, 53, "Output"]
}, Open  ]],
Cell[15961, 566, 93, 2, 31, "Text"],

Cell[CellGroupData[{
Cell[16079, 572, 100, 2, 53, "Input"],
Cell[16182, 576, 82, 2, 53, "Output"]
}, Open  ]],
Cell[16279, 581, 76, 0, 31, "Text"],

Cell[CellGroupData[{
Cell[16380, 585, 95, 2, 53, "Input"],
Cell[16478, 589, 60, 2, 53, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[16587, 597, 38, 0, 52, "Subsubsection"],
Cell[16628, 599, 499, 10, 73, "Text"],

Cell[CellGroupData[{
Cell[17152, 613, 198, 4, 74, "Input"],
Cell[17353, 619, 70, 2, 53, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[17460, 626, 208, 5, 74, "Input"],
Cell[17671, 633, 70, 2, 53, "Output"]
}, Open  ]],
Cell[17756, 638, 147, 3, 31, "Text"],

Cell[CellGroupData[{
Cell[17928, 645, 148, 3, 53, "Input"],
Cell[18079, 650, 60, 2, 53, "Output"]
}, Open  ]],
Cell[18154, 655, 102, 2, 53, "Input"],
Cell[18259, 659, 387, 10, 52, "Text"],

Cell[CellGroupData[{
Cell[18671, 673, 81, 2, 53, "Input"],
Cell[18755, 677, 105, 2, 53, "Output"]
}, Open  ]],
Cell[18875, 682, 296, 8, 52, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[19208, 695, 42, 0, 52, "Subsubsection"],
Cell[19253, 697, 463, 15, 52, "Text"],

Cell[CellGroupData[{
Cell[19741, 716, 143, 3, 53, "Input"],
Cell[19887, 721, 668, 18, 48, "Print"],
Cell[20558, 741, 342, 10, 48, "Print"],
Cell[20903, 753, 346, 10, 48, "Print"],
Cell[21252, 765, 420, 12, 48, "Print"],
Cell[21675, 779, 316, 9, 48, "Print"],
Cell[21994, 790, 424, 11, 48, "Print"],
Cell[22421, 803, 397, 10, 48, "Print"],
Cell[22821, 815, 319, 9, 48, "Print"],
Cell[23143, 826, 539, 13, 100, "Print"],
Cell[23685, 841, 357, 10, 62, "Print"],
Cell[24045, 853, 686, 17, 62, "Print"],
Cell[24734, 872, 472, 12, 62, "Print"],
Cell[25209, 886, 427, 12, 62, "Print"],
Cell[25639, 900, 757, 20, 48, "Print"],
Cell[26399, 922, 70, 2, 53, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[26530, 931, 35, 0, 79, "Section"],

Cell[CellGroupData[{
Cell[26590, 935, 50, 0, 52, "Subsubsection"],
Cell[26643, 937, 1195, 31, 391, "Text"],

Cell[CellGroupData[{
Cell[27863, 972, 83, 2, 53, "Input"],
Cell[27949, 976, 98, 2, 53, "Output"]
}, Open  ]],
Cell[28062, 981, 769, 30, 52, "Text"],

Cell[CellGroupData[{
Cell[28856, 1015, 89, 2, 53, "Input"],
Cell[28948, 1019, 88, 2, 53, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[29073, 1026, 78, 2, 53, "Input"],
Cell[29154, 1030, 88, 2, 53, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[29279, 1037, 76, 2, 53, "Input"],
Cell[29358, 1041, 77, 2, 53, "Output"]
}, Open  ]],
Cell[29450, 1046, 147, 4, 31, "Text"],

Cell[CellGroupData[{
Cell[29622, 1054, 79, 2, 53, "Input"],
Cell[29704, 1058, 175, 3, 20, "Message"],
Cell[29882, 1063, 104, 3, 53, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[30047, 1073, 39, 0, 79, "Section"],

Cell[CellGroupData[{
Cell[30111, 1077, 37, 0, 52, "Subsubsection"],
Cell[30151, 1079, 647, 16, 94, "Text"],

Cell[CellGroupData[{
Cell[30823, 1099, 135, 3, 62, "Input"],
Cell[30961, 1104, 190, 4, 37, "Message"],
Cell[31154, 1110, 162, 4, 62, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[31353, 1119, 827, 16, 297, "Input"],
Cell[32183, 1137, 74, 2, 53, "Output"]
}, Open  ]],
Cell[32272, 1142, 185, 6, 31, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[32494, 1153, 35, 0, 52, "Subsubsection"],
Cell[32532, 1155, 2081, 48, 409, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[34650, 1208, 37, 0, 52, "Subsubsection"],
Cell[34690, 1210, 275, 8, 52, "Text"],

Cell[CellGroupData[{
Cell[34990, 1222, 381, 8, 116, "Input"],
Cell[35374, 1232, 603, 13, 48, "Print"],
Cell[35980, 1247, 257, 5, 48, "Print"],
Cell[36240, 1254, 697, 16, 48, "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[36986, 1276, 39, 0, 52, "Subsubsection"],
Cell[37028, 1278, 329, 8, 52, "Text"],

Cell[CellGroupData[{
Cell[37382, 1290, 557, 10, 148, "Input"],
Cell[37942, 1302, 917, 25, 56, "Print"],
Cell[38862, 1329, 602, 17, 54, "Print"],
Cell[39467, 1348, 606, 17, 54, "Print"],
Cell[40076, 1367, 945, 27, 56, "Print"],
Cell[41024, 1396, 350, 11, 48, "Print"],
Cell[41377, 1409, 659, 18, 54, "Print"],
Cell[42039, 1429, 717, 21, 62, "Print"],
Cell[42759, 1452, 1713, 47, 82, "Print"],
Cell[44475, 1501, 459, 12, 48, "Print"],
Cell[44937, 1515, 354, 10, 48, "Print"],
Cell[45294, 1527, 1080, 29, 75, "Print"],
Cell[46377, 1558, 429, 11, 48, "Print"],
Cell[46809, 1571, 313, 9, 48, "Print"],
Cell[47125, 1582, 1263, 33, 98, "Print"],
Cell[48391, 1617, 1073, 28, 74, "Print"],
Cell[49467, 1647, 705, 17, 50, "Print"],
Cell[50175, 1666, 550, 15, 50, "Print"],
Cell[50728, 1683, 468, 13, 50, "Print"],
Cell[51199, 1698, 972, 26, 56, "Print"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

